@@ -1,18 +1,16 @@
 /* -----------------------------------------------------------------------------
+ * See the LICENSE file for information on copyright, usage and redistribution
+ * of SWIG, and the README file for authors - http://www.swig.org/release.html.
+ *
  * cparse.h
  *
- *     SWIG parser module.
- *
- * Author(s) : David Beazley (beazley@cs.uchicago.edu)
- *
- * Copyright (C) 1999-2003.  The University of Chicago
- * See the file LICENSE for information on usage and redistribution.
- *
- * $Header: /cvsroot/swig/SWIG/Source/CParse/cparse.h,v 1.18 2006/01/10 17:19:21 marcelomatus Exp $
+ * SWIG parser module.
  * ----------------------------------------------------------------------------- */
 
-#ifndef CPARSE_H_
-#define CPARSE_H_
+/* $Header: /cvsroot/swig/SWIG/Source/CParse/cparse.h,v 1.19 2006/03/06 22:50:56 wsfulton Exp $ */
+
+#ifndef SWIG_CPARSE_H_
+#define SWIG_CPARSE_H_
 
 #include "swig.h"
 #include "swigwarn.h"
