@@ -1,18 +1,13 @@
 /* -----------------------------------------------------------------------------
- * scanner.cxx
+ * See the LICENSE file for information on copyright, usage and redistribution
+ * of SWIG, and the README file for authors - http://www.swig.org/release.html.
  *
- *     SWIG1.1 tokenizer.
+ * scanner.c
  *
- * Author(s) : David Beazley (beazley@cs.uchicago.edu)
- *
- * Copyright (C) 1998-2000.  The University of Chicago
- * Copyright (C) 1995-1998.  The University of Utah and The Regents of the
- *                           University of California.
- *
- * See the file LICENSE for information on usage and redistribution.
+ * SWIG tokenizer.
  * ----------------------------------------------------------------------------- */
 
-char cvsroot_cscanner_c[] = "$Header: /cvsroot/swig/SWIG/Source/CParse/cscanner.c,v 1.25 2006/02/09 20:50:00 marcelomatus Exp $";
+char cvsroot_cscanner_c[] = "$Header: /cvsroot/swig/SWIG/Source/CParse/cscanner.c,v 1.29 2006/03/07 22:02:54 wsfulton Exp $";
 
 #include "cparse.h"
 #include "parser.h"
@@ -75,10 +70,10 @@ static void
 scanner_locator(String *loc) {
   if (Equal(loc,"@SWIG@"))  {    
     /* End locator. */
-    expanding_macro = 0;
+    if (expanding_macro) --expanding_macro;
   } else {
     /* Begin locator. */
-    expanding_macro = 1;
+    ++expanding_macro;
   }
 }
 
@@ -152,11 +147,11 @@ scanner_locator(String *loc) {
 }
 #endif
 
-/**************************************************************
+/* ----------------------------------------------------------------------------
  * scanner_init()
  *
  * Initialize buffers
- **************************************************************/
+ * ------------------------------------------------------------------------- */
 
 void scanner_init() {
   yybuffer = (char *) malloc(YYBSIZE);
@@ -166,11 +161,11 @@ void scanner_init() {
   scanner_ccode = NewStringEmpty();
 }
 
-/**************************************************************
+/* ----------------------------------------------------------------------------
  * scanner_file(FILE *f)
  *
  * Start reading from new file
- **************************************************************/
+ * ------------------------------------------------------------------------- */
 void scanner_file(DOHFile *f) {
   InFile *in;
 
@@ -185,11 +180,11 @@ void scanner_file(DOHFile *f) {
   cparse_line = 1;
 }
 
-/**************************************************************
+/* ----------------------------------------------------------------------------
  * scanner_close()
  *
  * Close current input file and go to next
- **************************************************************/
+ * ------------------------------------------------------------------------- */
 
 void scanner_close() {
   InFile *p;
@@ -207,13 +202,13 @@ void scanner_close() {
   in_head = p;
 }
 
-/**************************************************************
+/* ----------------------------------------------------------------------------
  * char nextchar()
  *
  * gets next character from input.
  * If we're in inlining mode, we actually retrieve a character
  * from inline_yybuffer instead.
- **************************************************************/
+ * ------------------------------------------------------------------------- */
 
 char nextchar() {
     int c = 0;
@@ -253,7 +248,7 @@ void retract(int n) {
   if (yylen < 0) yylen = 0;
 }
 
-/**************************************************************
+/* ----------------------------------------------------------------------------
  * start_inline(char *text, int line)
  *
  * This grabs a chunk of text and tries to inline it into
@@ -262,7 +257,7 @@ void retract(int n) {
  *
  * If we're already in inlining mode, we will save the code
  * as a new fragment.
- **************************************************************/
+ * ------------------------------------------------------------------------- */
 
 void start_inline(char *text, int line) {
   InFile *in;
@@ -282,11 +277,11 @@ void start_inline(char *text, int line) {
   cparse_line = line;
 }
 
-/**************************************************************
+/* ----------------------------------------------------------------------------
  * yycomment(char *, int line)
  *
  * Inserts a comment into a documentation entry.
- **************************************************************/
+ * ------------------------------------------------------------------------- */
 
 /*
 void yycomment(char *a, int b, int c) {
@@ -366,7 +361,7 @@ skip_balanced(int startchar, int endchar) {
     return;
 }
 
-/**************************************************************
+/* ----------------------------------------------------------------------------
  * void skip_decl(void)
  *
  * This tries to skip over an entire declaration.   For example
@@ -376,7 +371,7 @@ skip_balanced(int startchar, int endchar) {
  * or
  *  friend ostream& operator<<(ostream&, const char *s) { };
  *
- **************************************************************/
+ * ------------------------------------------------------------------------- */
 
 void skip_decl(void) {
   char c;
@@ -512,12 +507,12 @@ static void get_escape() {
   return;
 }
 
-/**************************************************************
+/* ----------------------------------------------------------------------------
  * int yylook()
  *
  * Lexical scanner.
  * See Aho,Sethi, and Ullman,  pg. 106
- **************************************************************/
+ * ------------------------------------------------------------------------- */
 
 int yylook(void) {
 
@@ -692,7 +687,7 @@ int yylook(void) {
 	    if (loc && (strncmp(loc,"@SWIG",4) == 0)&& (*(loc+Len(comment)-1) == '@')) {
 	      /* Locator */
 	      scanner_locator(comment);
-	      Clear(comment);
+	      yylen = 0;
 	      state = 0;
 	    } else {
 	      yylen = 0;
@@ -1041,11 +1036,11 @@ void scanner_next_token(int tok) {
   next_token = tok;
 }
 
-/**************************************************************
+/* ----------------------------------------------------------------------------
  * int yylex()
  *
  * Gets the lexene and returns tokens.
- *************************************************************/
+ * ------------------------------------------------------------------------- */
 
 int yylex(void) {
 
