@@ -1,15 +1,13 @@
 /* ----------------------------------------------------------------------------- 
+ * See the LICENSE file for information on copyright, usage and redistribution
+ * of SWIG, and the README file for authors - http://www.swig.org/release.html.
+ *
  * templ.c
  *
- *     Expands a template into a specialized version.   
- * 
- * Author(s) : David Beazley (beazley@cs.uchicago.edu)
- *
- * Copyright (C) 1999-2000.  The University of Chicago
- * See the file LICENSE for information on usage and redistribution.	
+ * Expands a template into a specialized version.   
  * ----------------------------------------------------------------------------- */
 
-char cvsroot_templ_c[] = "$Header: /cvsroot/swig/SWIG/Source/CParse/templ.c,v 1.30 2006/01/31 17:18:31 marcelomatus Exp $";
+char cvsroot_templ_c[] = "$Header: /cvsroot/swig/SWIG/Source/CParse/templ.c,v 1.31 2006/03/06 22:50:56 wsfulton Exp $";
 
 #include "swig.h"
 #include "swigkeys.h"
