@@ -9,7 +9,7 @@
  * See the file LICENSE for information on usage and redistribution.	
  * ----------------------------------------------------------------------------- */
 
-char cvsroot_list_c[] = "$Header: /cvsroot/swig/SWIG/Source/DOH/list.c,v 1.6 2005/04/24 20:34:50 wsfulton Exp $";
+char cvsroot_list_c[] = "$Header: /cvsroot/swig/SWIG/Source/DOH/list.c,v 1.8 2005/11/28 17:32:56 marcelomatus Exp $";
 
 #include "dohint.h"
 
@@ -238,7 +238,7 @@ List_str(DOH *lo) {
     DOH *s;
     int i;
     List *l = (List *) ObjData(lo);
-    s = NewString("");
+    s = NewStringEmpty();
     if (ObjGetMark(lo)) {
       Printf(s,"List(%x)", lo);
       return s;
@@ -324,6 +324,7 @@ DohObjInfo DohListType = {
     List_len,        /* doh_len */
     0,               /* doh_hash    */
     0,               /* doh_cmp */
+    0,               /* doh_equal    */
     List_first,               /* doh_first    */
     List_next,               /* doh_next     */
     List_setfile,               /* doh_setfile */
