@@ -10,7 +10,7 @@
  * See the file LICENSE for information on usage and redistribution.	
  * ----------------------------------------------------------------------------- */
 
-char cvsroot_string_c[] = "$Header: /cvsroot/swig/SWIG/Source/DOH/string.c,v 1.17 2005/08/26 07:06:10 marcelomatus Exp $";
+char cvsroot_string_c[] = "$Header: /cvsroot/swig/SWIG/Source/DOH/string.c,v 1.28 2006/01/23 22:58:49 marcelomatus Exp $";
 
 #include "dohint.h"
 
@@ -37,6 +37,11 @@ String_data(DOH *so) {
   return (void *) s->str;
 }
 
+char *
+DohString_char(DOH *so) {
+  return (char *) String_data(so);
+}
+
 /* -----------------------------------------------------------------------------
  * int String_dump() - Serialize a string onto out
  * ----------------------------------------------------------------------------- */
@@ -65,7 +70,7 @@ CopyString(DOH *so) {
   String *str;
   String *s = (String *) ObjData(so);
   str = (String *) DohMalloc(sizeof(String));
-  str->hashkey = -1;
+  str->hashkey = s->hashkey;
   str->sp = s->sp;
   str->line = s->line;
   str->file = s->file;
@@ -87,18 +92,16 @@ CopyString(DOH *so) {
 static void
 DelString(DOH *so) {
   String *s = (String *) ObjData(so);
-  s->hashkey = -1;
   DohFree(s->str);
-  s->str = 0;
   DohFree(s);
 }
 
 /* -----------------------------------------------------------------------------
- * String_len() - Length of a string
+ * DohString_len() - Length of a string
  * ----------------------------------------------------------------------------- */
 
-static int
-String_len(DOH *so) {
+int
+DohString_len(DOH *so) {
   String *s = (String *) ObjData(so);
   return s->len;
 }
@@ -132,6 +135,40 @@ String_cmp(DOH *so1, DOH *so2)
   return -1;
 }
 
+/* -----------------------------------------------------------------------------
+ * int String_equal() - Say if two string are equal
+ * ----------------------------------------------------------------------------- */
+
+int
+DohString_equal(DOH *so1, DOH *so2)
+{
+  String *s1 = (String *) ObjData(so1);
+  String *s2 = (String *) ObjData(so2);
+  register int len = s1->len;
+  if (len != s2->len) {
+    return 0;
+  } else {
+    register char *c1 = s1->str;
+    register char *c2 = s2->str;
+#if 0
+    register int mlen = len >> 2;
+    register int i = mlen;
+    for (; i; --i) {
+      if (*(c1++) != *(c2++)) return 0;
+      if (*(c1++) != *(c2++)) return 0;
+      if (*(c1++) != *(c2++)) return 0;
+      if (*(c1++) != *(c2++)) return 0;
+    }
+    for (i = len - (mlen << 2); i; --i) {
+      if (*(c1++) != *(c2++)) return 0;
+    }
+    return 1;
+#else
+    return memcmp(c1, c2, len) == 0;
+#endif
+  }
+}
+
 /* -----------------------------------------------------------------------------
  * int String_hash() - Compute string hash value
  * ----------------------------------------------------------------------------- */
@@ -139,31 +176,51 @@ String_cmp(DOH *so1, DOH *so2)
 static int 
 String_hash(DOH *so) {
   String *s = (String *) ObjData(so);
-  char *c;
-  int   i, h = 0, len;
-
-  if (s->hashkey >= 0) return s->hashkey;
-  c = s->str;
-  len = s->len > 50 ? 50 : s->len;
-  for (i = 0; i < len; i++) {
-    h = (((h << 5) + *(c++)));
+  if (s->hashkey >= 0) {
+    return s->hashkey;
+  } else {
+    register char *c = s->str;
+    register int len = s->len > 50 ? 50 : s->len;
+    register int h = 0;
+    register int mlen = len >> 2;
+    register int i = mlen;
+    for (; i; --i) {
+      h = (h << 5) + *(c++);
+      h = (h << 5) + *(c++);
+      h = (h << 5) + *(c++);
+      h = (h << 5) + *(c++);
+    }
+    for (i = len - (mlen << 2); i; --i) {
+      h = (h << 5) + *(c++);
+    }
+    h &= 0x7fffffff;
+    s->hashkey = h;
+    return h;
   }
-  h = h & 0x7fffffff;
-  s->hashkey = h;
-  return h;
 }  
 
 /* -----------------------------------------------------------------------------
- * static add(String *s, const char *newstr) - Append to s
+ * DohString_append(String *s, const char *newstr) - Append to s
  * ----------------------------------------------------------------------------- */
 
-static void
-add(String *s, const char *newstr) {
-  int   oldlen, newlen, newmaxsize, l, i, sp;
+void
+DohString_append(DOH *so, DOH *str) {
+  int   oldlen, newlen, newmaxsize, l, sp;
   char *tc;
+  String *s = (String *) ObjData(so);
+  char *newstr = 0;
+
+  if (DohCheck(str)) {
+    String *ss = (String *) ObjData(str);
+    newstr = (char*) String_data((DOH*)str);
+    l = ss->len;
+  } else {
+    newstr = (char *) (str);
+    l = (int) strlen(newstr);
+  }
   if (!newstr) return;
   s->hashkey = -1;
-  l = (int) strlen(newstr);
+
   oldlen = s->len;
   newlen = oldlen+l + 1;
   if (newlen >= s->maxsize-1) {
@@ -174,18 +231,20 @@ add(String *s, const char *newstr) {
     s->maxsize = newmaxsize;
   }
   tc = s->str;
-  strcpy(tc+oldlen,newstr);
+  memcpy(tc+oldlen,newstr,l+1);
   sp = s->sp;
   if (sp >= oldlen) {
+    int i  = oldlen + l - sp;
     tc += sp;
-    for (i = sp; i < oldlen+l; i++,tc++) {
-      if (*tc == '\n') s->line++;
+    for (; i ; --i) {
+      if (*(tc++) == '\n') s->line++;
     }
     s->sp = oldlen+l;
   }
   s->len += l;
 }
 
+
 /* -----------------------------------------------------------------------------
  * void String_clear() - Clear a string
  * ----------------------------------------------------------------------------- */
@@ -208,29 +267,38 @@ String_clear(DOH *so)
 static int 
 String_insert(DOH *so, int pos, DOH *str)
 {
-  String *s = (String *) ObjData(so);
+  String *s;
   char *nstr;
   int   len;
   char *data;
 
-  data = (char *) DohData(str);
-  nstr = s->str;
-
-  s->hashkey = -1;
   if (pos == DOH_END) {
-    add(s, data);
+    DohString_append(so, str);
     return 0;
   }
 
+
+  s = (String *) ObjData(so);
+  s->hashkey = -1;
+  if (DohCheck(str)) {
+    String *ss = (String *) ObjData(str);
+    data = (char *)String_data(str);
+    len = ss->len;
+  } else {
+    data = (char *) (str);
+    len = (int) strlen(data);
+  }
+  nstr = s->str;
+
   if (pos < 0) pos = 0;
   else if (pos > s->len) pos = s->len;
   
   /* See if there is room to insert the new data */
-  len = Len(str);  
   while (s->maxsize <= s->len+len) {
-    s->str = (char *) DohRealloc(s->str,2*s->maxsize);
+    int newsize = 2*s->maxsize;
+    s->str = (char *) DohRealloc(s->str,newsize);
     assert(s->str);
-    s->maxsize *= 2;
+    s->maxsize = newsize;
   }
   memmove(s->str+pos+len, s->str+pos, (s->len - pos));
   memcpy(s->str+pos,data,len);
@@ -368,7 +436,6 @@ static int
 String_seek(DOH *so, long offset, int whence)
 {
   int    pos, nsp, inc;
-  int prev;
   String *s = (String *) ObjData(so);
   if (whence == SEEK_SET) pos = 0;
   else if (whence == SEEK_CUR) pos = s->sp;
@@ -387,15 +454,31 @@ String_seek(DOH *so, long offset, int whence)
   inc = (nsp > s->sp) ? 1 : -1;
 
   {
+#if 0
     register int sp = s->sp;
     register char *tc = s->str;
     register int len = s->len;
     while (sp != nsp) {
-      prev = sp + inc;
+      int prev = sp + inc;
       if (prev>=0 && prev<=len && tc[prev] == '\n')
 	s->line += inc;
       sp+=inc;
     }
+#else
+    register int sp = s->sp;
+    register char *tc = s->str;
+    if (inc > 0) {
+      while (sp != nsp) {
+	if (tc[++sp] == '\n')
+	  ++s->line;
+      }
+    } else {
+      while (sp != nsp) {
+	if (tc[--sp] == '\n')
+	  --s->line;
+      }
+    }
+#endif
     s->sp = sp;
   }
   assert (s->sp >= 0);
@@ -417,34 +500,30 @@ String_tell(DOH *so)
  * int String_putc()
  * ----------------------------------------------------------------------------- */
 
-static int
-String_putc(DOH *so, int ch)
+int
+DohString_putc(DOH *so, int ch)
 {
-  register int len, maxsize, sp;
   String *s = (String *) ObjData(so);
+  register int len = s->len;
+  register int sp = s->sp;
   s->hashkey = -1;
-  len = s->len;
-  sp = s->sp;
   if (sp >= len) {
-    register char *tc;
-    maxsize = s->maxsize;
+    register int maxsize = s->maxsize;
+    register char *tc = s->str;
     if (len > (maxsize-2)) {
-      s->str = (char *) DohRealloc(s->str,2*maxsize);
-      assert(s->str);
-      s->maxsize = 2*maxsize;
+      maxsize *= 2;
+      tc = (char *) DohRealloc(tc, maxsize);
+      assert(tc);
+      s->maxsize = (int)maxsize;
+      s->str = tc;
     }
-    tc = s->str + len;
-    *(tc++) = ch;
-    if (sp >= len) {
-      s->sp = len+1;
-      *tc = 0;
-      if (ch == '\n') s->line++;
-    }
-    s->len = len+1;
+    tc += sp;
+    *tc = (char) ch; *(++tc) = 0;
+    s->len = s->sp = sp + 1;
   } else {
     s->str[s->sp++] = (char) ch;
-    if (ch == '\n') s->line++;
   }
+  if (ch == '\n') s->line++;
   return ch;
 }
 
@@ -452,8 +531,8 @@ String_putc(DOH *so, int ch)
  * int String_getc()
  * ----------------------------------------------------------------------------- */
 
-static int 
-String_getc(DOH *so)
+int 
+DohString_getc(DOH *so)
 {
   int c;
   String *s = (String *) ObjData(so);
@@ -461,7 +540,7 @@ String_getc(DOH *so)
     c = EOF;
   else
     c = (int) s->str[s->sp++];
-  if (c == '\n') s->line++;
+  if (c == '\n') s->line++; 
   return c;
 }
 
@@ -469,8 +548,8 @@ String_getc(DOH *so)
  * int String_ungetc()
  * ----------------------------------------------------------------------------- */
 
-static int 
-String_ungetc(DOH *so, int ch)
+int 
+DohString_ungetc(DOH *so, int ch)
 {
   String *s = (String *) ObjData(so);
   if (ch == EOF) return ch;
@@ -480,7 +559,6 @@ String_ungetc(DOH *so, int ch)
   return ch;
 }
 
-
 /* -----------------------------------------------------------------------------
  * replace_simple(String *str, char *token, char *rep, int flags, int count)
  *
@@ -590,8 +668,6 @@ replace_simple(String *str, char *token, char *rep, int flags, int count, char *
   register char *base;
   int i;
 
-  str->hashkey = -1;
-
   /* Figure out if anything gets replaced */
   if (!strlen(token)) return 0;
 
@@ -601,6 +677,8 @@ replace_simple(String *str, char *token, char *rep, int flags, int count, char *
 
   if (!s) return 0;    /* No matches.  Who cares */
 
+  str->hashkey = -1;
+
   if (flags & DOH_REPLACE_NOQUOTE) noquote = 1;
 
   /* If we are not replacing inside quotes, we need to do a little extra work */
@@ -882,9 +960,9 @@ static DohListMethods StringListMethods = {
 static DohFileMethods StringFileMethods = {
   String_read,
   String_write,
-  String_putc,
-  String_getc,
-  String_ungetc,
+  DohString_putc,
+  DohString_getc,
+  DohString_ungetc,
   String_seek,
   String_tell,
   0,              /* close */
@@ -903,9 +981,10 @@ DohObjInfo DohStringType = {
     String_str,        /* doh_str */
     String_data,       /* doh_data */
     String_dump,       /* doh_dump */
-    String_len,        /* doh_len */
+    DohString_len,     /* doh_len */
     String_hash,       /* doh_hash    */
     String_cmp,        /* doh_cmp */
+    DohString_equal,      /* doh_equal */
     0,               /* doh_first    */
     0,               /* doh_next     */
     String_setfile,    /* doh_setfile */
@@ -917,7 +996,7 @@ DohObjInfo DohStringType = {
     &StringFileMethods,   /* doh_file */
     &StringStringMethods, /* doh_string */
     0,                    /* doh_position */
-    0,
+    0
 };
 
 
@@ -933,16 +1012,24 @@ DohNewString(const DOH *so)
     int l = 0, max;
     String *str;
     char *s;
-    if (DohCheck(so)) s = Char(so);
-    else s = (char *) so;
+    int hashkey = -1;
+    if (DohCheck(so)) {
+      str = (String *) ObjData(so);
+      s = (char *)String_data((String *)so);
+      l = s ? str->len : 0;
+      hashkey = str->hashkey;
+    } else {
+      s = (char *) so;
+      l = s ? (int) strlen(s) : 0;
+    }
+    
     str = (String *) DohMalloc(sizeof(String));
-    str->hashkey = -1;
+    str->hashkey = hashkey;
     str->sp = 0;
     str->line = 1;
     str->file = 0;
     max = INIT_MAXSIZE;
     if (s) {
-      l = (int) strlen(s);
       if ((l+1) > max) max = l+1;
     }
     str->str = (char *) DohMalloc(max);
@@ -959,6 +1046,26 @@ DohNewString(const DOH *so)
 }
 
 
+/* -----------------------------------------------------------------------------
+ * NewStringEmpty() - Create a new string
+ * ----------------------------------------------------------------------------- */
+
+DOHString *
+DohNewStringEmpty()
+{
+  int max = INIT_MAXSIZE;
+  String *str = (String *) DohMalloc(sizeof(String));
+  str->hashkey = 0;
+  str->sp = 0;
+  str->line = 1;
+  str->file = 0;
+  str->str = (char *) DohMalloc(max);
+  str->maxsize = max;
+  str->str[0] = 0;
+  str->len = 0;
+  return DohObjMalloc(&DohStringType,str);
+}
+
 /* -----------------------------------------------------------------------------
  * NewStringWithSize(const char *c, int len) - Create a new string
  * ----------------------------------------------------------------------------- */
@@ -969,8 +1076,13 @@ DohNewStringWithSize(const DOH *so, int len)
     int l = 0, max;
     String *str;
     char *s;
-    if (DohCheck(so)) s = Char(so);
-    else s = (char *) so;
+    if (DohCheck(so)) {
+      s = (char *)String_data((String *)so);
+    }
+    else {
+      s = (char *) so;
+    }
+    
     str = (String *) DohMalloc(sizeof(String));
     str->hashkey = -1;
     str->sp = 0;
@@ -1006,7 +1118,7 @@ DohNewStringf(const DOH *fmt, ...)
   va_list ap;
   DOH *r;
   va_start(ap,fmt);
-  r = NewString("");
+  r = NewStringEmpty();
   DohvPrintf(r,Char(fmt),ap);
   va_end(ap);
   return (DOHString *) r;
@@ -1022,7 +1134,13 @@ DohNewStringf(const DOH *fmt, ...)
  * ----------------------------------------------------------------------------- */
 
 int DohStrcmp(const DOHString_or_char *s1, const DOHString_or_char *s2) {
-  return strcmp(Char(s1),Char(s2));
+  const char *c1 = Char(s1);
+  const char *c2 = Char(s2);
+  if (c1 && c2) {
+    return strcmp(c1, c2);
+  } else {
+    return c1 < c2;
+  }
 }
 
 int DohStrncmp(const DOHString_or_char *s1, const DOHString_or_char *s2, int n) {
