@@ -1,19 +1,17 @@
-/********************************************************************
- * ALLEGROCL module for SWIG
+/* ----------------------------------------------------------------------------- 
+ * See the LICENSE file for information on copyright, usage and redistribution
+ * of SWIG, and the README file for authors - http://www.swig.org/release.html.
  *
- * Author : Ahmon Dancy
- * Major restructuring: Mikel Bancroft (mikel@franz.com) and Dirk Gerrits.
+ * allegrocl.cxx
  *
- * Please read the file LICENSE for the copyright and terms by which
- * SWIG can be used and distributed.
- *
- ********************************************************************/
+ * ALLEGROCL language module for SWIG.
+ * ----------------------------------------------------------------------------- */
 
-char cvsroot_allegrocl_cxx[] = "$Header: /cvsroot/swig/SWIG/Source/Modules/allegrocl.cxx,v 1.21 2006/01/14 11:26:56 mkoeppe Exp $";
+char cvsroot_allegrocl_cxx[] = "$Header: /cvsroot/swig/SWIG/Source/Modules/allegrocl.cxx,v 1.30 2006/03/21 07:15:38 mutandiz Exp $";
 
-#include <ctype.h>
 #include "swigmod.h"
 #include "cparse.h"
+#include <ctype.h>
 
 // #define ALLEGROCL_DEBUG
 // #define ALLEGROCL_WRAP_DEBUG
@@ -27,9 +25,10 @@ static File *f_cxx;
 static File *f_cxx_header=0;
 static File *f_cxx_wrapper=0;
 
+static String *module_name=0;
 const char *identifier_converter="identifier-convert-null";
 
-static bool CWrap = false;  // generate wrapper file for C code?
+static bool CWrap = true;  // generate wrapper file for C code by default. most correct.
 static bool Generate_Wrapper = false;
 
 static String *current_namespace=NewString("");
@@ -45,7 +44,7 @@ static String *anon_type_name=NewString("anontype");
 static int anon_type_count=0;
 
 // stub
-String * convert_literal(String *num_param, String *type);
+String * convert_literal(String *num_param, String *type, bool try_to_split = true);
 
 class ALLEGROCL : public Language {
 public:
@@ -626,12 +625,15 @@ String *get_ffi_type(SwigType *ty, const String_or_char *name) {
      into lisp code to generate the def-foreign-type name */
   
 #ifdef ALLEGROCL_TYPE_DEBUG
-  Printf(stderr, "inside g_f_t: looking up %s\n", ty);
+  Printf(stderr, "inside g_f_t: looking up '%s' '%s'\n", ty, name);
 #endif
 
   String *found_type = lookup_defined_foreign_type(ty);
 
   if (found_type) {
+#ifdef ALLEGROCL_TYPE_DEBUG
+    Printf(stderr, "found_type '%s'\n", found_type);
+#endif
     return (Strcmp(found_type,"forward-reference") ?
             Copy(found_type) : NewString(":void"));
   } else {
@@ -639,7 +641,10 @@ String *get_ffi_type(SwigType *ty, const String_or_char *name) {
 
     if (typemap) {
       String *typespec = Getattr(typemap, "code");
-      
+
+#ifdef ALLEGROCL_TYPE_DEBUG
+    Printf(stderr, "found typemap '%s'\n", typespec);
+#endif
       return NewString(typespec);
     }     
 
@@ -828,26 +833,59 @@ String *strip_parens(String *string) {
 
 int ALLEGROCL :: validIdentifier(String *s) {
   char *c = Char(s);
-  if (*c && !isalpha(*c) && *c != '_') return 0;
+
+  bool got_dot = false;
+  bool only_dots = true;
+
+  /* Check that s is a valid common lisp symbol. There's a lot of leeway here.
+     A common lisp symbol is essentially any token that's not a number and
+     does not consist of only dots. 
+
+     We are expressly not allowing spaces in identifiers here, but spaces
+     could be added via the identifier converter. */
   while (*c) {
-    if (!isalnum(*c) && *c != '_') return 0;
+    if (*c == '.') {
+      got_dot = true;
+    } else {
+      only_dots = false;
+    }
+    if (!isgraph(*c)) return 0;
     c++;
   }
-  return 1;
+
+  return (got_dot && only_dots) ? 0 : 1;
 }
 
 String *infix_to_prefix(String *val, char split_op, const String *op, String *type) {
   List *ored = Split(val, split_op, -1);
+
+  // some float hackery
+  if ( ((split_op == '+') || (split_op == '-')) && Len(ored) == 2 &&
+       (SwigType_type(type) == T_FLOAT || SwigType_type(type) == T_DOUBLE ||
+	SwigType_type(type) == T_LONGDOUBLE) ) {
+    // check that we're not splitting a float
+    String *possible_result = convert_literal(val, type, false);
+    if (possible_result) return possible_result;
+   
+  }
+
+  // try parsing the split results. if any part fails, kick out.
+  bool part_failed = false;
   if (Len(ored) > 1) {
     String *result = NewStringf("(%s", op);
     for (Iterator i = First(ored); i.item; i = Next(i)) {
       String *converted = convert_literal(i.item, type);
-      Printf(result, " %s", converted);
-      Delete(converted);
+      if(converted) {
+	Printf(result, " %s", converted);
+	Delete(converted);
+      } else {
+	part_failed = true;
+	break;
+      }
     }
     Printf(result, ")");
     Delete(ored);
-    return result;
+    return part_failed ? 0 : result;
   }
   else {
     Delete(ored);
@@ -855,39 +893,76 @@ String *infix_to_prefix(String *val, char split_op, const String *op, String *ty
   return 0;
 }
 
-/* to be called by code generating the lisp interface */
-String * convert_literal(String *num_param, String *type) {
+/* To be called by code generating the lisp interface
+   Will return a containing the literal based on type.
+   Will return null if there are problems.
+
+   try_to_split defaults to true (see stub above).
+ */
+String * convert_literal(String *literal, String *type, bool try_to_split) {
+  String *num_param = Copy(literal);
   String *trimmed = trim(num_param);
   String *num=strip_parens(trimmed), *res=0;
   char *s=Char(num);
 
+  String *ns = listify_namespace(current_namespace);
+
   // very basic parsing of infix expressions.
-  if( (res = infix_to_prefix(num, '|', "logior", type)) ) return res;
-  if( (res = infix_to_prefix(num, '&', "logand", type)) ) return res;
-  if( (res = infix_to_prefix(num, '^', "logxor", type)) ) return res;
-  if( (res = infix_to_prefix(num, '*', "*", type)) ) return res;  
-  if( (res = infix_to_prefix(num, '/', "/", type)) ) return res;  
-  if( (res = infix_to_prefix(num, '+', "+", type)) ) return res;
-  if( (res = infix_to_prefix(num, '-', "-", type)) ) return res;  
-  //  if( (res = infix_to_prefix(num, '<<', "ash", type)) ) return res;  
+  if(try_to_split) {
+    if( (res = infix_to_prefix(num, '|', "logior", type)) ) return res;
+    if( (res = infix_to_prefix(num, '&', "logand", type)) ) return res;
+    if( (res = infix_to_prefix(num, '^', "logxor", type)) ) return res;
+    if( (res = infix_to_prefix(num, '*', "*", type)) ) return res;  
+    if( (res = infix_to_prefix(num, '/', "/", type)) ) return res;  
+    if( (res = infix_to_prefix(num, '+', "+", type)) ) return res;
+    if( (res = infix_to_prefix(num, '-', "-", type)) ) return res;  
+    //  if( (res = infix_to_prefix(num, '<<', "ash", type)) ) return res;  
+  }
 
   if (SwigType_type(type) == T_FLOAT ||
       SwigType_type(type) == T_DOUBLE ||
       SwigType_type(type) == T_LONGDOUBLE) {
     // Use CL syntax for float literals 
     String *oldnum = Copy(num);
-    int fsuffixes = Replaceall(num, "f", "") + Replaceall(num, "F", "");
-    int lsuffixes = Replaceall(num, "l", "") + Replaceall(num, "L", "");
-    char const *lisp_exp = fsuffixes ? "f" : (lsuffixes ? "l" : "d");
-    int exponents = Replaceall(num, "e", lisp_exp) +
-                    Replaceall(num, "E", lisp_exp);
-    if ((fsuffixes + lsuffixes) > 1 || exponents > 1) {
-      Printf(stderr, "Weird!! number %s looks invalid.\n", oldnum);
-      SWIG_exit(EXIT_FAILURE);
+
+    // careful. may be a float identifier or float constant.
+    char *num_start = Char(num);
+    char *num_end = num_start + strlen(num_start) -1;
+
+    bool is_literal = isdigit(*num_start) || (*num_start == '.');
+
+    String *lisp_exp = 0;
+    if(is_literal) {
+      if (*num_end == 'f' || *num_end == 'F') {
+	lisp_exp = NewString("f");
+      } else {
+	lisp_exp = NewString("d");
+      }
+
+      if (*num_end == 'l' || *num_end == 'L' || *num_end == 'f' || *num_end == 'F') {
+	*num_end = '\0';
+	num_end--;
+      }
+
+      int exponents = Replaceall(num, "e", lisp_exp) +
+	              Replaceall(num, "E", lisp_exp);
+
+      if (!exponents)
+	Printf(num, "%s0", lisp_exp);
+
+      if (exponents > 1 || (exponents + Replaceall(num,".",".") == 0)) {
+	// Printf(stderr, "Can't parse '%s' as type '%s'.\n", oldnum, type);
+	Delete(num);
+	num = 0;
+      }
+    } else {
+      String *id = NewStringf("#.(swig-insert-id \"%s\" %s :type :constant)",
+			      num, ns);
+      Delete(num);
+      num = id;
     }
-    if (!exponents)
-      Printf(num, "%s0", lisp_exp);
-    Delete(oldnum); Delete(trimmed);
+
+    Delete(oldnum); Delete(trimmed); Delete(ns);
     return num;
   }
   else if (SwigType_type(type) == T_CHAR) {
@@ -902,7 +977,6 @@ String * convert_literal(String *num_param, String *type) {
   }
   else if (allegrocl->validIdentifier(num)) {
     /* convert C/C++ identifiers to CL symbols */
-    String *ns = listify_namespace(current_namespace);
     res = NewStringf("#.(swig-insert-id \"%s\" %s :type :constant)", num, ns);
     Delete(num); Delete(trimmed); Delete(ns);
     return res;
@@ -1066,9 +1140,10 @@ void emit_full_class(Node *n) {
         (!storage_type || Strcmp(storage_type,"typedef")))) {
       String *access = Getattr(c,"access");
 
-      // hack. why would decl have a value of "variableHandler"?
+      // hack. why would decl have a value of "variableHandler" and now "0"?
       String *childDecl = Getattr(c,"decl");
-      if(!Strcmp(childDecl,"variableHandler"))
+      // Printf(stderr,"childDecl = '%s' (%s)\n", childDecl, Getattr(c,"view"));
+      if(!Strcmp(childDecl,"0"))
 	childDecl = NewString("");
 
       SwigType *childType=NewStringf("%s%s", childDecl,
@@ -1242,11 +1317,17 @@ void emit_enum_type_no_wrap(Node *n) {
       if(!Getattr(c,"error")) {
 	String *val = Getattr(c,"enumvalue");
 	if(!val) val = Getattr(c,"enumvalueex");
-
-	val = convert_literal(val,Getattr(c,"type"));
-
+	String *converted_val = convert_literal(val,Getattr(c,"type"));
 	String *valname = Getattr(c,"sym:name");
-	Printf(f_clhead,"(swig-defconstant \"%s\" %s)\n", valname, val);
+
+	if(converted_val) { 
+	  Printf(f_clhead,"(swig-defconstant \"%s\" %s)\n", valname, converted_val);
+	  Delete(converted_val);
+	} else {
+	  Swig_warning(WARN_LANG_DISCARD_CONST, Getfile(n), Getline(n),
+		       "Unable to parse enum value '%s'. Setting to NIL\n", val);
+	  Printf(f_clhead,"(swig-defconstant \"%s\" nil #| %s |#)\n", valname, val);
+	}
       }
     }
   }
@@ -1439,11 +1520,11 @@ void ALLEGROCL :: main(int argc, char *argv[]) {
 }
 
 int ALLEGROCL :: top(Node *n) {
-  String *module=Getattr(n, "name");  
+  module_name=Getattr(n, "name");  
   String *cxx_filename=Getattr(n, "outfile");  
   String *cl_filename=NewString("");
 
-  Printf(cl_filename, "%s%s.cl", SWIG_output_directory(), module);
+  Printf(cl_filename, "%s%s.cl", SWIG_output_directory(), module_name);
 
   f_cl=NewFile(cl_filename, "w");
   if (!f_cl) {
@@ -1477,15 +1558,20 @@ int ALLEGROCL :: top(Node *n) {
                ";; the definition file, not here.\n\n"
                "(defpackage :swig\n"
                "  (:use :common-lisp :ff :excl)\n"
-               "  (:export #:*swig-identifier-converter* #:*swig-module-name*))\n"
+               "  (:export #:*swig-identifier-converter* #:*swig-module-name*\n"
+	       "           #:*void*))\n"
                "(in-package :swig)\n\n"  
                "(eval-when (compile load eval)\n"
                "  (defparameter *swig-identifier-converter* '%s)\n"
                "  (defparameter *swig-module-name* :%s))\n\n",
-         identifier_converter, module);
+         identifier_converter, module_name);
   Printf(f_cl, "(defpackage :%s\n"
                "  (:use :common-lisp :swig :ff :excl))\n\n",
-         module);
+         module_name);
+
+  Printf(f_clhead, "(in-package :%s)\n", module_name);
+
+  // Swig_print_tree(n);
 
   Language::top(n);
 
@@ -1838,6 +1924,39 @@ Node *parent_node_skipping_extends(Node* n)
   return result;
 }
 
+/* -----------------------------------------------------------------------------
+ * emit_num_lin_arguments()
+ *
+ * Calculate the total number of arguments.   This function is safe for use
+ * with multi-valued typemaps which may change the number of arguments in
+ * strange ways.
+ * ----------------------------------------------------------------------------- */
+
+int emit_num_lin_arguments(ParmList *parms) {
+  Parm *p = parms;
+  int   nargs = 0;
+
+  while (p) {
+    // Printf(stderr,"enla: '%s' lin='%x'\n", Getattr(p,"name"), Getattr(p,"tmap:lin"));
+    if (Getattr(p,"tmap:lin")) {
+      nargs += GetInt(p,"tmap:lin:numinputs");
+      p = Getattr(p,"tmap:lin:next");
+    } else {
+      p = nextSibling(p);
+    }
+  }
+
+  /* DB 04/02/2003: Not sure this is necessary with tmap:in:numinputs */
+  /*
+  if (parms && (p = Getattr(parms,"emit:varargs"))) {
+    if (!nextSibling(p)) {
+      nargs--;
+    }
+  }
+  */
+  return nargs;
+}
+
 String *id_converter_type(SwigType const *type)
 {
   SwigType *t = Copy(type);
@@ -1942,6 +2061,12 @@ static ParmList *parmlist_with_names(ParmList *pl)
       Setattr(p2, "name", Getattr(p2, "lname"));
     Setattr(p2, "name", strip_namespaces(Getattr(p2, "name")));
     Setattr(p2, "tmap:ctype", Getattr(p, "tmap:ctype"));
+    
+    String *temp = Getattr(p,"tmap:lin");
+    if (temp) {
+      Setattr(p2, "tmap:lin", temp);
+      Setattr(p2, "tmap:lin:next", Getattr(p,"tmap:lin:next"));
+    }
   }
   return pl2;
 }
@@ -2059,7 +2184,8 @@ IDargs* id_converter_arguments(Node *n)
   if (Getattr(n, "sym:overloaded")) {
     if(result->arity) Delete(result->arity);
     result->arity = NewStringf("%d",
-                 emit_num_arguments(Getattr(n, "wrap:parms")));
+			       // emit_num_arguments(Getattr(n, "wrap:parms")));
+			       emit_num_lin_arguments(Getattr(n, "wrap:parms")));
   }
 
   SetVoid(n, "allegrocl:id-converter-args", result);
@@ -2158,7 +2284,7 @@ int ALLEGROCL :: emit_dispatch_defun(Node *n) {
 
   int last_arity = -1;
   for (Iterator i = First(overloads); i.item; i = Next(i)) {
-    int arity = emit_num_arguments(Getattr(i.item, "wrap:parms"));
+    int arity = emit_num_lin_arguments(Getattr(i.item, "wrap:parms"));
     if (arity == last_arity) continue;
 
     Printf(f_clwrap, "%s%d", last_arity == -1 ? "" : " ", arity);
@@ -2193,8 +2319,7 @@ int ALLEGROCL :: emit_defun(Node *n, File *f_cl) {
 
   String *funcname = Getattr(n, "allegrocl:old-sym:name");
   if (!funcname) funcname = Getattr(n, "sym:name");
-  String *mangled_name=mangle_name(n, "ACL", Getattr(n,"allegrocl:package"));
-  // SwigType *type=Copy(Getattr(n, "type"));
+  String *mangled_name = Getattr(n,"wrap:name");
   ParmList *pl = parmlist_with_names(Getattr(n, "wrap:parms"));
 
   // attach typemap info.
@@ -2202,15 +2327,14 @@ int ALLEGROCL :: emit_defun(Node *n, File *f_cl) {
   Swig_typemap_attach_parms("lin", pl, wrap);
   Swig_typemap_lookup_new("lout",n,"result",0);
 
-  // prime the pump.
-  Printf(wrap->code,"$body");
+  SwigType *result_type = Swig_cparse_type(Getattr(n,"tmap:ctype"));
+  // prime the pump, with support for OUTPUT, INOUT typemaps.
+  Printf(wrap->code,"(let ((ACL_ffresult swig:*void*)\n        ACL_result)\n  $body\n  (if (eq ACL_ffresult swig:*void*)\n    (values-list ACL_result)\n   (values-list (cons ACL_ffresult ACL_result))))");
 
   Parm *p;
   int largnum = 0, argnum=0, first=1;
   // int varargs=0;
-  SwigType *result_type = Swig_cparse_type(Getattr(n,"tmap:ctype"));
-
-  if (CPlusPlus)
+  if (Generate_Wrapper)
   {
     String *extra_parms = id_converter_arguments(n)->noname_str();
     if (Getattr(n, "sym:overloaded"))
@@ -2224,7 +2348,8 @@ int ALLEGROCL :: emit_defun(Node *n, File *f_cl) {
   // Just C
   else
   {
-    Printf(f_cl, "(swig-defun (\"%s\")\n", funcname);
+    Printf(f_cl, "(swig-defun (\"%s\" \"%s\")\n", funcname,
+	   Generate_Wrapper ? mangled_name : funcname);
   }
 
   //////////////////////////////////////
@@ -2243,7 +2368,8 @@ int ALLEGROCL :: emit_defun(Node *n, File *f_cl) {
     String *largs = NewString("");
 
     for (p=pl; p; p=nextSibling(p), argnum++, largnum++) {
-      SwigType *argtype=Getattr(p, "type");
+      // SwigType *argtype=Getattr(p, "type");
+      SwigType *argtype = Swig_cparse_type(Getattr(p,"tmap:ctype"));
 
       if (!first) {
 	Printf(f_cl, "\n   ");
@@ -2254,10 +2380,26 @@ int ALLEGROCL :: emit_defun(Node *n, File *f_cl) {
       } else {
 	String *argname=NewStringf("PARM%d_%s", largnum, Getattr(p, "name"));
 
-	// String *ffitype=get_ffi_type(argtype, argname);
-	String *ffitype=compose_foreign_type(argtype);
-	String *lisptype=get_lisp_type(argtype, argname);
-      
+	String *ffitype = compose_foreign_type(argtype);
+	String *deref_ffitype;
+	String *temp = Copy(argtype);
+
+	if(SwigType_ispointer(temp)) {
+	  SwigType_pop(temp);
+	  deref_ffitype = compose_foreign_type(temp);
+	} else {
+	  deref_ffitype = Copy(ffitype);
+	}
+
+	Delete(temp);
+
+	// String *lisptype=get_lisp_type(argtype, argname);
+	String *lisptype=get_lisp_type(Getattr(p,"type"), Getattr(p,"name"));
+	
+#ifdef ALLEGROCL_DEBUG
+	Printf(stderr,"lisptype of '%s' '%s' = '%s'\n", Getattr(p,"type"), Getattr(p,"name"), lisptype);
+#endif
+	
 	// while we're walking the parameters, generating LIN
 	// wrapper code...
 	Setattr(p,"lname",NewStringf("SWIG_arg%d", largnum));
@@ -2269,16 +2411,25 @@ int ALLEGROCL :: emit_defun(Node *n, File *f_cl) {
 	  Printf(largs," %s",lname);
 	  Replaceall(parm_code,"$in", argname);
 	  Replaceall(parm_code,"$out", lname);
-	  
+	  Replaceall(parm_code,"$in_fftype", ffitype);
+	  Replaceall(parm_code,"$*in_fftype", deref_ffitype);
 	  Replaceall(wrap->code,"$body", parm_code);
 	}
 	
 	String *dispatchtype=Getattr(n, "sym:overloaded") ?
 	  dispatching_type(p) :
 	  NewString("");
-      
-	Printf(f_cl, "(%s %s %s %s)", argname, dispatchtype, ffitype, lisptype);
-	first=0;
+
+	// if this parameter has been removed from the C/++ wrapper
+	// it shouldn't be in the lisp wrapper either.
+	if(!checkAttribute(p,"tmap:in:numinputs","0")) {
+	  Printf(f_cl, "(%s %s %s %s %s)", 
+		 // parms in the ff wrapper, but not in the lisp wrapper.
+		 (checkAttribute(p,"tmap:lin:numinputs","0") ? ":p-" : ":p+"),
+		 argname, dispatchtype, ffitype, lisptype);
+	
+	  first=0;
+	}
 
 	Delete(ffitype);
 	Delete(lisptype);
@@ -2329,8 +2480,11 @@ int ALLEGROCL :: emit_defun(Node *n, File *f_cl) {
   //                 Getattr(n,"name"), cl_t);
   //  }
 
-  Replaceall(wrap->code,"$body", NewStringf("(swig-ff-call%s)",
-                                            wrap->locals));
+  Replaceall(wrap->code,"$body", NewStringf("(swig-ff-call%s)", wrap->locals));
+//   Replaceall(wrap->code,"$body", 
+// 	     (!Strcmp(result_type,"void") ?
+// 	      NewStringf("(swig-ff-call%s)", wrap->locals) :
+//	      NewStringf("(push (swig-ff-call%s) ACL_result)", wrap->locals)));
   String* ldestructor = Copy(lclass);
   if (ff_foreign_ptr)
     Replaceall(ldestructor, ldestructor, "identity");
@@ -2402,6 +2556,7 @@ int ALLEGROCL :: functionWrapper(Node *n) {
 
   // Attach the standard typemaps 
   Swig_typemap_attach_parms("ctype", parms, wrap);
+  Swig_typemap_attach_parms("lin", parms, wrap);
   emit_attach_parmmaps(parms, wrap);
 
   String *mangled = mangle_name(n);
@@ -2442,10 +2597,12 @@ int ALLEGROCL :: functionWrapper(Node *n) {
   int i; Parm *p;
   for (i = 0, p=parms; i < num_arguments; i++) {
 
-    while (checkAttribute(p,"tmap:in:numinputs","0")) {
+    while (p && checkAttribute(p,"tmap:in:numinputs","0")) {
       p = Getattr(p,"tmap:in:next");
     }
 
+    if(!p) break;
+
     SwigType *c_parm_type = Swig_cparse_type(Getattr(p, "tmap:ctype"));
     String *arg = NewStringf("l%s", Getattr(p,"lname"));
 
@@ -2582,8 +2739,39 @@ int ALLEGROCL :: constantWrapper(Node *n) {
 #ifdef ALLEGROCL_DEBUG
   Printf(stderr, "constant %s\n", Getattr(n, "name"));
 #endif
+
+  if(Generate_Wrapper) {
+    // Setattr(n,"wrap:name",mangle_name(n, "ACLPP"));
+    String *const_type = Getattr(n,"type");
+
+    String *const_val = 0;
+    String *raw_const = Getattr(n,"value");
+
+    if(SwigType_type(const_type) == T_STRING) {
+      const_val = NewStringf("\"%s\"",raw_const);
+    } else if (SwigType_type(const_type) == T_CHAR) {
+      const_val = NewStringf("'%s'",raw_const);
+    } else {
+      const_val = Copy(raw_const);
+    }
+
+    SwigType_add_qualifier(const_type,"const");
+    SwigType_add_qualifier(const_type,"static");
+   
+    String *ppcname = NewStringf("ACLppc_%s",Getattr(n,"name"));
+    Printf(f_cxx,"static const %s = %s;\n", SwigType_lstr(const_type,ppcname),
+	   const_val);
+
+    Setattr(n,"name",ppcname);
+    SetFlag(n,"feature:immutable");
+
+    Delete(const_val);
+    return variableWrapper(n);
+  }
+
   String *type=Getattr(n, "type");
-  String *converted_value=convert_literal(Getattr(n, "value"), type);
+  String *value = Getattr(n,"value");
+  String *converted_value=convert_literal(value, type);
   String *name=Getattr(n, "sym:name");
 
   Setattr(n, "allegrocl:kind", "constant");
@@ -2594,8 +2782,14 @@ int ALLEGROCL :: constantWrapper(Node *n) {
          name, type, converted_value);
 #endif
 
-  Printf(f_clwrap, "(swig-defconstant \"%s\" %s)\n",
-         name, converted_value);
+  if(converted_value) {
+    Printf(f_clwrap, "(swig-defconstant \"%s\" %s)\n",
+	   name, converted_value);
+  } else {
+    Swig_warning(WARN_LANG_DISCARD_CONST, Getfile(n), Getline(n),
+		 "Unable to parse constant value '%s'. Setting to NIL\n", value);
+    Printf(f_clwrap, "(swig-defconstant \"%s\" nil #| %s |#)\n", name, value);
+  }
 
   Delete(converted_value);
  
@@ -2639,14 +2833,15 @@ int ALLEGROCL :: variableWrapper(Node *n) {
   Setattr(n, "allegrocl:old-sym:name", Getattr(n, "sym:name"));
 
   // Let SWIG generate a get/set function pair.
-  if(CPlusPlus) return Language::variableWrapper(n);
+  if(Generate_Wrapper) return Language::variableWrapper(n);
 
-  /*
   String *name = Getattr(n, "name");
   SwigType *type = Getattr(n,"type");
   SwigType *ctype;
   SwigType *rtype = SwigType_typedef_resolve_all(type);
 
+  String *mangled_name = mangle_name(n);
+
   int pointer_added = 0;
 
   if(SwigType_isclass(rtype)) {
@@ -2658,20 +2853,18 @@ int ALLEGROCL :: variableWrapper(Node *n) {
   ctype = SwigType_str(type,0);
   // EXPORT <SwigType_str> <mangled_name>;
   // <SwigType_str> <mangled_name> = <name>;
-  //  Printf(f_cxx, "EXPORT %s %s;\n%s %s = %s%s;\n", ctype, mangled_name,
-  //	 ctype, mangled_name, (pointer_added ? "&" : ""), name);
+   Printf(f_cxx, "EXPORT %s %s;\n%s %s = %s%s;\n", ctype, mangled_name,
+	  ctype, mangled_name, (pointer_added ? "&" : ""), name);
 
   Printf(f_cl, "(swig-defvar \"%s\" :type %s)\n",
-	 Getattr(n,"sym:name"), 
+	 mangled_name,
 	 ((SwigType_isconst(type)) ? ":constant" : ":variable"));
-  */
-
   /*
   Printf(f_cxx, "// swigtype: %s\n", SwigType_typedef_resolve_all(Getattr(n,"type")));
   Printf(f_cxx, "// vwrap: %s\n", compose_foreign_type(SwigType_strip_qualifiers(Copy(rtype))));
   */
 
-  // Delete(mangled_name);
+  Delete(mangled_name);
 
   return SWIG_OK;
 }
@@ -2762,7 +2955,7 @@ int ALLEGROCL :: classHandler(Node *n) {
       Strcmp(kind, "class") == 0 ||
       Strcmp(kind, "union") == 0)
   {
-    if (CPlusPlus)
+    if (Generate_Wrapper)
       return cppClassHandler(n);
     else
       return cClassHandler(n);
@@ -2868,6 +3061,8 @@ int ALLEGROCL :: cppClassHandler(Node *n) {
 				     Getattr(c,"type"));
     if(!SwigType_isfunction(childType))
       Delete(compose_foreign_type(childType));
+
+    Delete(childType);
   }
 #ifdef ALLEGROCL_CLASS_DEBUG
   Printf(stderr, "   MANUAL walk DONE.\n");
