@@ -1,22 +1,17 @@
 /* ----------------------------------------------------------------------------- 
+ * See the LICENSE file for information on copyright, usage and redistribution
+ * of SWIG, and the README file for authors - http://www.swig.org/release.html.
+ *
  * allocate.cxx
  *
- *     This module tries to figure out which classes and structures support
- *     default constructors and destructors in C++.   There are several rules that
- *     define this behavior including pure abstract methods, private sections,
- *     and non-default constructors in base classes.  See the ARM or
- *     Doc/Manual/SWIGPlus.html for details.
- * 
- * Author(s) : David Beazley (beazley@cs.uchicago.edu)
- *
- * Copyright (C) 1998-2002.  The University of Chicago
- * Copyright (C) 1995-1998.  The University of Utah and The Regents of the
- *                           University of California.
- *
- * See the file LICENSE for information on usage and redistribution.	
+ * This module tries to figure out which classes and structures support
+ * default constructors and destructors in C++.   There are several rules that
+ * define this behavior including pure abstract methods, private sections,
+ * and non-default constructors in base classes.  See the ARM or
+ * Doc/Manual/SWIGPlus.html for details.
  * ----------------------------------------------------------------------------- */
 
-char cvsroot_allocate_cxx[] = "$Header: /cvsroot/swig/SWIG/Source/Modules/allocate.cxx,v 1.63 2006/02/08 02:06:15 marcelomatus Exp $";
+char cvsroot_allocate_cxx[] = "$Header: /cvsroot/swig/SWIG/Source/Modules/allocate.cxx,v 1.64 2006/03/06 22:50:56 wsfulton Exp $";
 
 #include "swigmod.h"
 #include "cparse.h"
