@@ -1,20 +1,15 @@
 /* -----------------------------------------------------------------------------
+ * See the LICENSE file for information on copyright, usage and redistribution
+ * of SWIG, and the README file for authors - http://www.swig.org/release.html.
+ *
  * emit.cxx
  *
- *     Useful functions for emitting various pieces of code.
- *
- * Author(s) : David Beazley (beazley@cs.uchicago.edu)
- *
- * Copyright (C) 1998-2000.  The University of Chicago
- * Copyright (C) 1995-1998.  The University of Utah and The Regents of the
- *                           University of California.
- *
- * See the file LICENSE for information on usage and redistribution.
+ * Useful functions for emitting various pieces of code.
  * ----------------------------------------------------------------------------- */
 
-#include "swigmod.h"
+char cvsroot_emit_cxx[] = "$Header: /cvsroot/swig/SWIG/Source/Modules/emit.cxx,v 1.51 2006/03/06 22:50:57 wsfulton Exp $";
 
-char cvsroot_emit_cxx[] = "$Header: /cvsroot/swig/SWIG/Source/Modules/emit.cxx,v 1.50 2006/01/30 22:22:12 marcelomatus Exp $";
+#include "swigmod.h"
 
 /* -----------------------------------------------------------------------------
  * emit_args()
