@@ -1,32 +1,13 @@
-/******************************************************************************
- * Simplified Wrapper and Interface Generator  (SWIG)
- *
- * Author : David Beazley
- *
- * Department of Computer Science
- * University of Chicago
- * 1100 E 58th Street
- * Chicago, IL  60637
- * beazley@cs.uchicago.edu
- *
- * Please read the file LICENSE for the copyright and terms by which SWIG
- * can be used and distributed.
- *****************************************************************************/
-
-char cvsroot_guile_cxx[] = "$Header: /cvsroot/swig/SWIG/Source/Modules/guile.cxx,v 1.36 2006/01/28 02:35:13 marcelomatus Exp $";
-
-/***********************************************************************
- * $Header: /cvsroot/swig/SWIG/Source/Modules/guile.cxx,v 1.36 2006/01/28 02:35:13 marcelomatus Exp $
+/* ----------------------------------------------------------------------------- 
+ * See the LICENSE file for information on copyright, usage and redistribution
+ * of SWIG, and the README file for authors - http://www.swig.org/release.html.
  *
  * guile.cxx
  *
- * Definitions for adding functions to Guile
- ***********************************************************************/
+ * Guile language module for SWIG.
+ * ----------------------------------------------------------------------------- */
 
-/***********************************************************************
- * GOOPS Support added by John Lenz <jelenz@wisc.edu> in June, 2003
- * Base code copied from chicken module, writen by Jonah Beckford
- ***********************************************************************/
+char cvsroot_guile_cxx[] = "$Header: /cvsroot/swig/SWIG/Source/Modules/guile.cxx,v 1.38 2006/03/07 21:25:28 mkoeppe Exp $";
 
 #include "swigmod.h"
 
@@ -452,7 +433,6 @@ public:
     }
     
     Printv(module_func,module_name,NIL);
-    if (goops)
     Replaceall(module_func,"-", "_");
     
     switch (linkage) {
