@@ -1,25 +1,20 @@
 /* -----------------------------------------------------------------------------
+ * See the LICENSE file for information on copyright, usage and redistribution
+ * of SWIG, and the README file for authors - http://www.swig.org/release.html.
+ *
  * lang.cxx
  *
- *     Language base class functions.  Default C++ handling is also implemented here.
- * 
- * Author(s) : David Beazley (beazley@cs.uchicago.edu)
- *
- * Copyright (C) 1998-2000.  The University of Chicago
- * Copyright (C) 1995-1998.  The University of Utah and The Regents of the
- *                           University of California.
- *
- * See the file LICENSE for information on usage and redistribution.	
+ * Language base class functions.  Default C++ handling is also implemented here.
  * ----------------------------------------------------------------------------- */
 
-char cvsroot_lang_cxx[] = "$Header: /cvsroot/swig/SWIG/Source/Modules/lang.cxx,v 1.144 2006/02/11 18:09:46 marcelomatus Exp $";
+char cvsroot_lang_cxx[] = "$Header: /cvsroot/swig/SWIG/Source/Modules/lang.cxx,v 1.153 2006/03/21 19:14:47 marcelomatus Exp $";
 
 #include "swigmod.h"
 #include "cparse.h"
 #include <ctype.h>
 
 static int director_mode = 0;   /* set to 0 on default */
-static int director_protected_mode = 0;   /* set to 0 on default */
+static int director_protected_mode = 1;   /* set to 1 on default */
 static int naturalvar_mode = 0;
 
 /* Set director_protected_mode */
@@ -1657,7 +1652,10 @@ String *vtable_method_id(Node *n)
   String *name = Getattr(n, "name");
   String *decl = Getattr(n, "decl");
   String *local_decl = SwigType_typedef_resolve_all(decl);
-  Node *method_id = NewStringf("%s|%s", name, local_decl);
+  String *tmp = SwigType_pop_function(local_decl);
+  Delete(local_decl);
+  local_decl = tmp;
+  Node *method_id = NewStringf("%s|%s", name, local_decl); 
   Delete(local_decl);
   return method_id;
 }
@@ -2027,7 +2025,28 @@ static void addCopyConstructor(Node *n)
   String *cc = NewStringf("r.q(const).%s", type);
   String *decl = NewStringf("f(%s).",cc);
   String *csymname = Getattr(n,"sym:name");
-  String *symname = Swig_name_make(cn, cname, last, decl, 0);
+  String *oldname = csymname;
+
+  if (Getattr(n,"allocate:has_constructor")) {
+    // to work properly with '%rename Class', we must look
+    // for any other constructor in the class, which has not been
+    // renamed, and use its name as oldname.
+    Node *c;
+    for (c = firstChild(n); c; c = nextSibling(c)) {
+      const char *tag = Char(nodeType(c));
+      if (strcmp(tag,"constructor") == 0) {
+	String *cname = Getattr(c,k_name);
+	String *csname = Getattr(c,k_symname);
+	String *clast = Swig_scopename_last(cname);  
+	if (Equal(csname, clast)) {
+	  oldname = csname;
+	  break;
+	}
+      }
+    }
+  }
+
+  String *symname = Swig_name_make(cn, cname, last, decl, oldname);
   if (!symname) {
     symname = Copy(csymname);
   }
@@ -2077,7 +2096,8 @@ static void addDefaultConstructor(Node *n)
   String *name = NewStringf("%s::%s",cname,last);
   String *decl = NewString("f().");
   String *csymname = Getattr(n,"sym:name");
-  String *symname = Swig_name_make(cn, cname, last, decl, 0);
+  String *oldname = csymname;
+  String *symname = Swig_name_make(cn, cname, last, decl, oldname);
   if (!symname) {
     symname = Copy(csymname);
   }
@@ -2519,7 +2539,6 @@ Language::copyconstructorHandler(Node *n) {
   Swig_ConstructorToFunction(n,ClassType, none_comparison, director_ctor,
 			     CPlusPlus, Getattr(n,"template") ? 0 : Extend);
   Setattr(n,"sym:name", mrename);
-  Printf(stderr,"Hello\n");
   functionWrapper(n);
   Delete(mrename);
   Swig_restore(n);
