@@ -1,12 +1,10 @@
 /* -----------------------------------------------------------------------------
+ * See the LICENSE file for information on copyright, usage and redistribution
+ * of SWIG, and the README file for authors - http://www.swig.org/release.html.
+ *
  * lua.cxx
  *
- *     Lua wrapper module.
- *
- * Author(s) : Mark Gossage (mark@gossage.cjb.net)
- *
- * Copyright (C) 1999-2000.  The University of Chicago
- * See the file LICENSE for information on usage and redistribution.
+ * Lua language module for SWIG.
  * ----------------------------------------------------------------------------- */
 
 /* NEW LANGUAGE NOTE:
@@ -42,12 +40,9 @@
 
 */
 
-char cvsroot_lua_cxx[] = "$Header: /cvsroot/swig/SWIG/Source/Modules/lua.cxx,v 1.9 2006/01/31 06:18:50 marcelomatus Exp $";
+char cvsroot_lua_cxx[] = "$Header: /cvsroot/swig/SWIG/Source/Modules/lua.cxx,v 1.11 2006/03/06 22:50:57 wsfulton Exp $";
 
 #include "swigmod.h"
-#ifndef MACSWIG
-#include "swigconfig.h"
-#endif
 
 /* NEW LANGUAGE NOTE:***********************************************
  most of the default options are handled by SWIG
