@@ -1,18 +1,15 @@
 /* -----------------------------------------------------------------------------
+ * See the LICENSE file for information on copyright, usage and redistribution
+ * of SWIG, and the README file for authors - http://www.swig.org/release.html.
+ *
  * main.cxx
  *
- *     Main entry point to the SWIG core.
- *
- * Author(s) : David Beazley (beazley@cs.uchicago.edu)
- *
- * Copyright (C) 1998-2000.  The University of Chicago
- * Copyright (C) 1995-1998.  The University of Utah and The Regents of the
- *                           University of California.
- *
- * See the file LICENSE for information on usage and redistribution.
+ * Main entry point to the SWIG core.
  * ----------------------------------------------------------------------------- */
 
-char cvsroot_main_cxx[] = "$Header: /cvsroot/swig/SWIG/Source/Modules/main.cxx,v 1.82 2006/02/01 08:37:52 marcelomatus Exp $";
+char cvsroot_main_cxx[] = "$Header: /cvsroot/swig/SWIG/Source/Modules/main.cxx,v 1.88 2006/03/20 22:05:28 wsfulton Exp $";
+
+#include "swigconfig.h"
 
 #if defined(_WIN32)
 #define WIN32_LEAN_AND_MEAN
@@ -53,10 +50,11 @@ static const char *usage1 = (const char*)"\
      -co <file>      - Check <file> out of the SWIG library\n\
      -copyctor       - Automatically generate copy constructors wherever possible\n\
      -cpperraswarn   - Treat the preprocessor #error statement as #warning (default)\n\
+     -copyright      - Display copyright notices\n\
      -debug_template - Display information for debugging templates\n\
      -debug_typemap  - Display information for debugging typemaps\n\
      -directors      - Turn on director mode for all the classes, mainly for testing\n\
-     -dirprot        - Turn on wrapping of protected members for director classes\n\
+     -dirprot        - Turn on wrapping of protected members for director classes (default)\n\
      -D<symbol>      - Define a symbol <symbol> (for conditional compilation)\n\
      -dump_classes   - Display information about the classes found in the interface\n\
      -dump_module    - Display information on the module node tree avoiding system nodes\n\
@@ -106,6 +104,8 @@ static const char *usage2 = (const char*)"\
 
 static const char *usage3 = (const char*)"\
      -notemplatereduce - Disable reduction of the typedefs in templates\n\
+     -O              - Enable the optimizations options: \n\
+                        -fastdispatch -fvirtual \n\
      -o <outfile>    - Set name of the output file to <outfile>\n\
      -oh <headfile>  - Set name of the output header file to <headfile>\n\
      -outdir <dir>   - Set language specific files output directory <dir>\n\
@@ -569,13 +569,18 @@ void SWIG_getoptions(int argc, char *argv[])
 	      Swig_arg_error();
 	    }
 	  } else if (strcmp(argv[i],"-version") == 0) {
+	      fprintf(stdout,"\nSWIG Version %s\n", swig_package_version());
+	      fprintf(stdout,"\nCompiled with %s [%s]\n", SWIG_CXX, SWIG_PLATFORM);
+	      fprintf(stdout,"Please see %s for reporting bugs and further information\n", PACKAGE_BUGREPORT);
+	      SWIG_exit (EXIT_SUCCESS);
+	  } else if (strcmp(argv[i],"-copyright") == 0) {
 	      fprintf(stdout,"\nSWIG Version %s\n", swig_package_version());
 	      fprintf(stdout,"Copyright (c) 1995-1998\n");
 	      fprintf(stdout,"University of Utah and the Regents of the University of California\n");
 	      fprintf(stdout,"Copyright (c) 1998-2005\n");
 	      fprintf(stdout,"University of Chicago\n");
-	      fprintf(stdout,"Compiled with %s [%s]\n", SWIG_CXX, SWIG_PLATFORM);
-	      fprintf(stdout,"\nPlease see %s for reporting bugs and further information\n", PACKAGE_BUGREPORT);
+	      fprintf(stdout,"Copyright (c) 2005-2006\n");
+	      fprintf(stdout,"Arizona Board of Regents (University of Arizona)\n");
 	      SWIG_exit (EXIT_SUCCESS);
 	  } else if (strncmp(argv[i],"-l",2) == 0) {
 	    // Add a new directory search path
@@ -711,7 +716,11 @@ void SWIG_getoptions(int argc, char *argv[])
 	  } else if (strcmp(argv[i],"-Fmicrosoft") == 0) {
             Swig_error_msg_format(EMF_MICROSOFT);
 	    Swig_mark_arg(i);
-	  } else if ((strcmp(argv[i],"-help") == 0) || (strcmp(argv[i],"--help") == 0)) {
+	  } else if (strcmp(argv[i],"-O") == 0) {
+	    Wrapper_virtual_elimination_mode_set(1);
+	    Wrapper_fast_dispatch_mode_set(1);
+	    Swig_mark_arg(i);
+	  } else if (strcmp(argv[i],"-help") == 0) {
 	    fputs(usage1,stdout);
 	    fputs(usage2,stdout);
 	    fputs(usage3,stdout);
@@ -788,7 +797,7 @@ int SWIG_main(int argc, char *argv[], Language *l) {
 
   /* Turn off directors mode */
   Wrapper_director_mode_set(0);
-  Wrapper_director_protected_mode_set(0);
+  Wrapper_director_protected_mode_set(1);
 
   // Check for SWIG_LIB environment variable
 
