@@ -1,27 +1,13 @@
-/******************************************************************************
- * Simplified Wrapper and Interface Generator  (SWIG)
- *
- * Author : David Beazley
- *
- * Department of Computer Science
- * University of Chicago
- * 1100 E 58th Street
- * Chicago, IL  60637
- * beazley@cs.uchicago.edu
- *
- * Please read the file LICENSE for the copyright and terms by which SWIG
- * can be used and distributed.
- *****************************************************************************/
-
-char cvsroot_mzscheme_cxx[] = "$Header: /cvsroot/swig/SWIG/Source/Modules/mzscheme.cxx,v 1.19 2006/01/28 02:36:13 marcelomatus Exp $";
-
-/***********************************************************************
- * $Header: /cvsroot/swig/SWIG/Source/Modules/mzscheme.cxx,v 1.19 2006/01/28 02:36:13 marcelomatus Exp $
+/* ----------------------------------------------------------------------------- 
+ * See the LICENSE file for information on copyright, usage and redistribution
+ * of SWIG, and the README file for authors - http://www.swig.org/release.html.
  *
  * mzscheme.cxx
  *
- * Definitions for adding functions to Mzscheme 101
- ***********************************************************************/
+ * Mzscheme language module for SWIG.
+ * ----------------------------------------------------------------------------- */
+
+char cvsroot_mzscheme_cxx[] = "$Header: /cvsroot/swig/SWIG/Source/Modules/mzscheme.cxx,v 1.20 2006/03/06 22:50:57 wsfulton Exp $";
 
 #include "swigmod.h"
 
