@@ -1,22 +1,13 @@
-/******************************************************************************
- * Simplified Wrapper and Interface Generator  (SWIG)
- *
- * Author : Art Yerkes
- * Modified from mzscheme.cxx : David Beazley
- *
- * Please read the file LICENSE for the copyright and terms by which SWIG
- * can be used and distributed.
- *****************************************************************************/
-
-char cvsroot_ocaml_cxx[] = "$Header: /cvsroot/swig/SWIG/Source/Modules/ocaml.cxx,v 1.65 2006/01/28 02:35:13 marcelomatus Exp $";
-
-/***********************************************************************
- * $Header: /cvsroot/swig/SWIG/Source/Modules/ocaml.cxx,v 1.65 2006/01/28 02:35:13 marcelomatus Exp $
+/* ----------------------------------------------------------------------------- 
+ * See the LICENSE file for information on copyright, usage and redistribution
+ * of SWIG, and the README file for authors - http://www.swig.org/release.html.
  *
  * ocaml.cxx
  *
- * Definitions for adding functions to Ocaml 101
- ***********************************************************************/
+ * Ocaml language module for SWIG.
+ * ----------------------------------------------------------------------------- */
+
+char cvsroot_ocaml_cxx[] = "$Header: /cvsroot/swig/SWIG/Source/Modules/ocaml.cxx,v 1.67 2006/03/07 22:02:54 wsfulton Exp $";
 
 #include "swigmod.h"
 
@@ -1463,9 +1454,9 @@ public:
 	return ret;
     }
 
-    /***************************************************************************
+    /* ----------------------------------------------------------------------------
      * BEGIN C++ Director Class modifications
-     ***************************************************************************/
+     * ------------------------------------------------------------------------- */
 
     /*
      * Modified polymorphism code for Ocaml language module.
