@@ -1,17 +1,15 @@
 /* ----------------------------------------------------------------------------- 
+ * See the LICENSE file for information on copyright, usage and redistribution
+ * of SWIG, and the README file for authors - http://www.swig.org/release.html.
+ *
  * overload.cxx
  *
- *     This file is used to analyze overloaded functions and methods.
- *     It looks at signatures and tries to gather information for
- *     building a dispatch function.
- * 
- * Author(s) : David Beazley (beazley@cs.uchicago.edu)
- *
- * Copyright (C) 1999-2000.  The University of Chicago
- * See the file LICENSE for information on usage and redistribution.	
+ * This file is used to analyze overloaded functions and methods.
+ * It looks at signatures and tries to gather information for
+ * building a dispatch function.
  * ----------------------------------------------------------------------------- */
 
-char cvsroot_overload_cxx[] = "$Header: /cvsroot/swig/SWIG/Source/Modules/overload.cxx,v 1.21 2006/02/05 04:07:16 marcelomatus Exp $";
+char cvsroot_overload_cxx[] = "$Header: /cvsroot/swig/SWIG/Source/Modules/overload.cxx,v 1.22 2006/03/06 22:50:57 wsfulton Exp $";
 
 #include "swigmod.h"
 
