@@ -1,19 +1,13 @@
 /* ----------------------------------------------------------------------------
+ * See the LICENSE file for information on copyright, usage and redistribution
+ * of SWIG, and the README file for authors - http://www.swig.org/release.html.
+ *
  * perl5.cxx
  *
- *     Generate Perl5 wrappers
- *
- * Author(s) : David Beazley (beazley@cs.uchicago.edu)
- *             Loic Dachary (loic@ceic.com)
- *             David Fletcher
- *             Gary Holt
- *             Jason Stewart (jasons@apache.org)
- *
- * Copyright (C) 1999-2000.  The University of Chicago
- * See the file LICENSE for information on usage and redistribution.
+ * Perl5 language module for SWIG.
  * ------------------------------------------------------------------------- */
 
-char cvsroot_perl5_cxx[] = "$Header: /cvsroot/swig/SWIG/Source/Modules/perl5.cxx,v 1.54 2006/02/11 20:33:52 marcelomatus Exp $";
+char cvsroot_perl5_cxx[] = "$Header: /cvsroot/swig/SWIG/Source/Modules/perl5.cxx,v 1.57 2006/03/07 22:02:54 wsfulton Exp $";
 
 #include "swigmod.h"
 #include "cparse.h"
@@ -749,7 +743,7 @@ public:
     } else if (!Getattr(n,"sym:nextSibling")) {
       /* Generate overloaded dispatch function */
       int maxargs, ii;
-      String *dispatch = Swig_overload_dispatch_cast(n,"(*PL_markstack_ptr++);SWIG_CALLXS(%s); return;",&maxargs);
+      String *dispatch = Swig_overload_dispatch_cast(n,"++PL_markstack_ptr; SWIG_CALLXS(%s); return;",&maxargs);
 	
       /* Generate a dispatch wrapper for all overloaded functions */
 
@@ -1067,38 +1061,38 @@ public:
     return SWIG_OK;
   }
 
-  /****************************************************************************
-   ***                      OBJECT-ORIENTED FEATURES
-   ****************************************************************************
-   *** These extensions provide a more object-oriented interface to C++
-   *** classes and structures.    The code here is based on extensions
-   *** provided by David Fletcher and Gary Holt.
-   ***
-   *** I have generalized these extensions to make them more general purpose
-   *** and to resolve object-ownership problems.
-   ***
-   *** The approach here is very similar to the Python module :
-   ***       1.   All of the original methods are placed into a single
-   ***            package like before except that a 'c' is appended to the
-   ***            package name.
-   ***
-   ***       2.   All methods and function calls are wrapped with a new
-   ***            perl function.   While possibly inefficient this allows
-   ***            us to catch complex function arguments (which are hard to
-   ***            track otherwise).
-   ***
-   ***       3.   Classes are represented as tied-hashes in a manner similar
-   ***            to Gary Holt's extension.   This allows us to access
-   ***            member data.
-   ***
-   ***       4.   Stand-alone (global) C functions are modified to take
-   ***            tied hashes as arguments for complex datatypes (if
-   ***            appropriate).
-   ***
-   ***       5.   Global variables involving a class/struct is encapsulated
-   ***            in a tied hash.
-   ***
-   ****************************************************************************/
+/* ----------------------------------------------------------------------------
+ *                      OBJECT-ORIENTED FEATURES
+ *
+ * These extensions provide a more object-oriented interface to C++
+ * classes and structures.    The code here is based on extensions
+ * provided by David Fletcher and Gary Holt.
+ *
+ * I have generalized these extensions to make them more general purpose
+ * and to resolve object-ownership problems.
+ *
+ * The approach here is very similar to the Python module :
+ *       1.   All of the original methods are placed into a single
+ *            package like before except that a 'c' is appended to the
+ *            package name.
+ *
+ *       2.   All methods and function calls are wrapped with a new
+ *            perl function.   While possibly inefficient this allows
+ *            us to catch complex function arguments (which are hard to
+ *            track otherwise).
+ *
+ *       3.   Classes are represented as tied-hashes in a manner similar
+ *            to Gary Holt's extension.   This allows us to access
+ *            member data.
+ *
+ *       4.   Stand-alone (global) C functions are modified to take
+ *            tied hashes as arguments for complex datatypes (if
+ *            appropriate).
+ *
+ *       5.   Global variables involving a class/struct is encapsulated
+ *            in a tied hash.
+ *
+ * ------------------------------------------------------------------------- */
   
   
   void setclassname(Node *n) {
