@@ -1,21 +1,17 @@
+/* ----------------------------------------------------------------------------- 
+ * See the LICENSE file for information on copyright, usage and redistribution
+ * of SWIG, and the README file for authors - http://www.swig.org/release.html.
+ *
+ * php4.cxx
+ *
+ * Php language module for SWIG.
+ * ----------------------------------------------------------------------------- */
+
 /*
- * PHP4 Support
- *
- * Richard Palmer
- * richard@magicality.org
- * Nov 2001
- *
- * Portions copyright Sun Microsystems (c) 2001
- * Tim Hockin <thockin@sun.com>
- *
- * Portions copyright Ananova Ltd (c) 2002
- * Sam Liddicott <sam@ananova.com>
- *
  * TODO: Replace stderr messages with Swig_warning
- *
  */
 
-char cvsroot_php4_cxx[] = "$Header: /cvsroot/swig/SWIG/Source/Modules/php4.cxx,v 1.28 2006/02/11 22:01:31 marcelomatus Exp $";
+char cvsroot_php4_cxx[] = "$Header: /cvsroot/swig/SWIG/Source/Modules/php4.cxx,v 1.34 2006/03/20 00:24:39 marcelomatus Exp $";
 
 #include "swigmod.h"
 
@@ -343,7 +339,7 @@ public:
     }
     
     Printf(f_extra,
-	   "# $Id: php4.cxx,v 1.28 2006/02/11 22:01:31 marcelomatus Exp $\n\n"
+	   "# $Id: php4.cxx,v 1.34 2006/03/20 00:24:39 marcelomatus Exp $\n\n"
 	   "LTLIBRARY_NAME          = php_%s.la\n",
 	   module);
     
@@ -393,7 +389,7 @@ public:
       SWIG_exit(EXIT_FAILURE);
     }
     
-    Printf(f_extra,"dnl $Id: php4.cxx,v 1.28 2006/02/11 22:01:31 marcelomatus Exp $\n");
+    Printf(f_extra,"dnl $Id: php4.cxx,v 1.34 2006/03/20 00:24:39 marcelomatus Exp $\n");
     Printf(f_extra,"dnl ***********************************************************************\n");
     Printf(f_extra,"dnl ** THIS config.m4 is provided for PHPIZE and PHP's consumption NOT\n");
     Printf(f_extra,"dnl ** for any part of the rest of the %s build system\n",module);
@@ -613,8 +609,8 @@ public:
     Printf(s_header, "ZEND_END_MODULE_GLOBALS(%s)\n", module );
     Printf(s_header, "ZEND_DECLARE_MODULE_GLOBALS(%s)\n",module );
     Printf(s_header, "#ifdef ZTS\n" );
-    Printf(s_header, "#define ErrorMsg() TSRMG(%s_globals_id, zend_%s_globals *, error_msg );\n",module,module);
-    Printf(s_header, "#define ErrorCode() TSRMG(%s_globals_id, zend_%s_globals *, error_code );\n",module,module);
+    Printf(s_header, "#define ErrorMsg() TSRMG(%s_globals_id, zend_%s_globals *, error_msg )\n",module,module);
+    Printf(s_header, "#define ErrorCode() TSRMG(%s_globals_id, zend_%s_globals *, error_code )\n",module,module);
     Printf(s_header, "#else\n" );
     Printf(s_header, "#define ErrorMsg() (%s_globals.error_msg)\n",module);
     Printf(s_header, "#define ErrorCode() (%s_globals.error_code)\n",module);
@@ -629,6 +625,7 @@ public:
 
     Printf(s_header, "\n");
     Printf(s_header, "void SWIG_ResetError() {\n");
+    Printf(s_header, "  TSRMLS_FETCH();\n");
     Printf(s_header, "  ErrorMsg() = default_error_msg;\n");
     Printf(s_header, "  ErrorCode() = default_error_code;\n");
     Printf(s_header, "}\n");
@@ -671,6 +668,9 @@ public:
     Printf(f_h, "#else\n" );
     Printf(f_h, "# define PHP_%s_API\n", cap_module );
     Printf(f_h, "#endif\n\n" );
+    Printf(f_h, "#ifdef ZTS\n" );
+    Printf(f_h, "#include \"TSRM.h\"\n" );
+    Printf(f_h, "#endif\n\n" );
     Printf(f_h, "PHP_MINIT_FUNCTION(%s);\n", module );
     Printf(f_h, "PHP_MSHUTDOWN_FUNCTION(%s);\n", module );
     Printf(f_h, "PHP_RINIT_FUNCTION(%s);\n", module );
@@ -874,7 +874,9 @@ public:
 
     Printv(f->code,dispatch,"\n",NIL);
 
-    Printf(f->code,"/*No matching function for overloaded '%s'*/\n", symname);
+    Printf(f->code,"ErrorCode() = E_ERROR;\n");
+    Printf(f->code,"ErrorMsg() = \"No matching function for overloaded '%s'\";\n", symname);
+    Printv(f->code,"zend_error(ErrorCode(),ErrorMsg());",NIL);
     Printf(f->code,"\n");
 
     Printv(f->code,"}\n",NIL);
@@ -1910,6 +1912,7 @@ public:
    * ------------------------------------------------------------ */
   
   virtual int constructorHandler(Node *n) {
+    char *name = GetChar(n, "name");
     char *iname = GetChar(n, "sym:name");
 
     if (shadow) {
@@ -1924,7 +1927,11 @@ public:
     
     if(shadow) {
       String *wname = NewStringf( "_wrap_new_%s", iname );
-      create_command( iname, wname );
+      if(!Getattr(n,"sym:overloaded") || !Getattr(n,"sym:nextSibling")) {
+        char *realname = iname ? iname : name;
+        String *php_function_name = Swig_name_construct(realname);
+        create_command(realname,Swig_name_wrapper(php_function_name));
+      }
       Delete(wname);
     }
     
@@ -2039,3 +2046,4 @@ extern "C" Language * swig_php(void) {
   return new_swig_php();
 }
  
+
