@@ -1,16 +1,13 @@
-/********************************************************************
- * Ruby module for SWIG
+/* ----------------------------------------------------------------------------- 
+ * See the LICENSE file for information on copyright, usage and redistribution
+ * of SWIG, and the README file for authors - http://www.swig.org/release.html.
  *
- * $Header: /cvsroot/swig/SWIG/Source/Modules/ruby.cxx,v 1.121 2006/02/05 04:08:00 marcelomatus Exp $
+ * ruby.cxx
  *
- * Copyright (C) 2000  Network Applied Communication Laboratory, Inc.
- * Copyright (C) 2000  Information-technology Promotion Agency, Japan
- *
- * Masaki Fukushima
- *
- ********************************************************************/
+ * Ruby language module for SWIG.
+ * ----------------------------------------------------------------------------- */
 
-char cvsroot_ruby_cxx[] = "$Header: /cvsroot/swig/SWIG/Source/Modules/ruby.cxx,v 1.121 2006/02/05 04:08:00 marcelomatus Exp $";
+char cvsroot_ruby_cxx[] = "$Header: /cvsroot/swig/SWIG/Source/Modules/ruby.cxx,v 1.123 2006/03/06 22:50:58 wsfulton Exp $";
 
 #include "swigmod.h"
 #include "cparse.h"
@@ -1175,7 +1172,8 @@ public:
       emit_action(n,f);
       
       if (director_method) {
-	Printf(f->code, "} catch (Swig::DirectorException&) {\n");
+	Printf(f->code, "} catch (Swig::DirectorException& e) {\n");
+	Printf(f->code, "  rb_exc_raise(e.getError());\n");
 	Printf(f->code, "  SWIG_fail;\n");
 	Printf(f->code, "}\n");
       }
