@@ -1,29 +1,21 @@
-/*******************************************************************************
+/* ----------------------------------------------------------------------------- 
+ * See the LICENSE file for information on copyright, usage and redistribution
+ * of SWIG, and the README file for authors - http://www.swig.org/release.html.
+ *
  * Simplified Wrapper and Interface Generator  (SWIG)
  *
  * swigmain.cxx
  *
- *     This file is the main entry point to SWIG.  It collects the command
- *     line options, registers built-in language modules, and instantiates
- *     a module for code generation.   If adding new language modules
- *     to SWIG, you would modify this file.
- *
- * Author : David Beazley
- *
- * Department of Computer Science
- * University of Chicago
- * 1100 E 58th Street
- * Chicago, IL  60637
- * beazley@cs.uchicago.edu
- *
- * Please read the file LICENSE for the copyright and terms by which SWIG
- * can be used and distributed.
- *******************************************************************************/
+ * This file is the main entry point to SWIG.  It collects the command
+ * line options, registers built-in language modules, and instantiates
+ * a module for code generation.   If adding new language modules
+ * to SWIG, you would modify this file.
+ * ----------------------------------------------------------------------------- */
 
-char cvsroot_swigmain_cxx[] = "$Header: /cvsroot/swig/SWIG/Source/Modules/swigmain.cxx,v 1.20 2006/01/07 23:34:31 wsfulton Exp $";
+char cvsroot_swigmain_cxx[] = "$Header: /cvsroot/swig/SWIG/Source/Modules/swigmain.cxx,v 1.23 2006/03/20 22:05:28 wsfulton Exp $";
 
-#include <ctype.h>
 #include "swigmod.h"
+#include <ctype.h>
 
 /* Module factories.  These functions are used to instantiate
    the built-in language modules.    If adding a new language
@@ -167,32 +159,34 @@ int main(int margc, char **margv) {
 
   /* Get options */
   for (i = 1; i < argc; i++) {
-      if (argv[i]) {
-	fac = Swig_find_module(argv[i]);
-	if (fac) {
-	  dl = (fac)();
-	  Swig_mark_arg(i);
-	} else if (strcmp(argv[i],"-nolang") == 0) {
-	  dl = new Language;
-	  Swig_mark_arg(i);
-	} else if ((strcmp(argv[i],"-dnone") == 0) ||
-		   (strcmp(argv[i],"-dhtml") == 0) ||
-		   (strcmp(argv[i],"-dlatex") == 0) ||
-		   (strcmp(argv[i],"-dascii") == 0) ||
-		   (strcmp(argv[i],"-stat") == 0))
-	  {
-	    Printf(stderr,"swig: Warning. %s option deprecated.\n",argv[i]);
-	    Swig_mark_arg(i);
-	  } else if (strcmp(argv[i],"-help") == 0) {
-	    Printf(stdout,"Target Language Options\n");
-	    for (int j = 0; modules[j].name; j++) {
-	      if (modules[j].help) {
-		Printf(stdout,"     %-15s - Generate %s wrappers\n", modules[j].name, modules[j].help);
-	      }
-	    }
-	    // Swig_mark_arg not called as the general -help options also need to be displayed later on
+    if (argv[i]) {
+      fac = Swig_find_module(argv[i]);
+      if (fac) {
+	dl = (fac)();
+	Swig_mark_arg(i);
+      } else if (strcmp(argv[i],"-nolang") == 0) {
+	dl = new Language;
+	Swig_mark_arg(i);
+      } else if ((strcmp(argv[i],"-dnone") == 0) ||
+		 (strcmp(argv[i],"-dhtml") == 0) ||
+		 (strcmp(argv[i],"-dlatex") == 0) ||
+		 (strcmp(argv[i],"-dascii") == 0) ||
+		 (strcmp(argv[i],"-stat") == 0))
+      {
+	Printf(stderr,"swig: Warning. %s option deprecated.\n",argv[i]);
+	Swig_mark_arg(i);
+      } else if ((strcmp(argv[i],"-help") == 0) || (strcmp(argv[i],"--help") == 0)) {
+        if (strcmp(argv[i],"--help") == 0)
+	  strcpy(argv[i], "-help");
+	Printf(stdout,"Target Language Options\n");
+	for (int j = 0; modules[j].name; j++) {
+	  if (modules[j].help) {
+	    Printf(stdout,"     %-15s - Generate %s wrappers\n", modules[j].name, modules[j].help);
 	  }
+	}
+	// Swig_mark_arg not called as the general -help options also need to be displayed later on
       }
+    }
   }
   if (!dl) {
     fac = Swig_find_module(SWIG_LANG);
