@@ -1,26 +1,13 @@
 /* -----------------------------------------------------------------------------
+ * See the LICENSE file for information on copyright, usage and redistribution
+ * of SWIG, and the README file for authors - http://www.swig.org/release.html.
+ *
  * tcl8.cxx
  *
- *     Tcl8.0 wrapper module.
- *
- * Author(s) : David Beazley (beazley@cs.uchicago.edu)
- *
- * Copyright (C) 1999-2000.  The University of Chicago
- * See the file LICENSE for information on usage and redistribution.
- *
- * Incr Tcl 3.x support by Alexey Dyachenko (dyachenko@fromru.com) 
- *
- * Based on 
- * itcl.cxx
- *  Author:  Bob Techentin
- *           based on tcl8 and python modules by David Beazley
- *
- * Module for creating Incr Tcl 3.x shadow classes
- * and Tcl 8.x native wrapper functions.
- *
+ * Tcl8 language module for SWIG.
  * ----------------------------------------------------------------------------- */
 
-char cvsroot_tcl8_cxx[] = "$Header: /cvsroot/swig/SWIG/Source/Modules/tcl8.cxx,v 1.45 2006/02/09 16:39:10 marcelomatus Exp $";
+char cvsroot_tcl8_cxx[] = "$Header: /cvsroot/swig/SWIG/Source/Modules/tcl8.cxx,v 1.48 2006/03/19 22:40:45 wsfulton Exp $";
 
 #include "swigmod.h"
 #include "cparse.h"
@@ -577,7 +564,7 @@ public:
     int addfail = 0;
     getf = NewWrapper();
     getname = Swig_name_get(iname);
-    Printv(getf->def,"SWIGINTERN char *",getname,"(ClientData clientData SWIGUNUSED, Tcl_Interp *interp, char *name1, char *name2, int flags) {",NIL);
+    Printv(getf->def,"SWIGINTERN const char *",getname,"(ClientData clientData SWIGUNUSED, Tcl_Interp *interp, char *name1, char *name2, int flags) {",NIL);
     Wrapper_add_local(getf,"value", "Tcl_Obj *value = 0");
     if ((tm = Swig_typemap_lookup_new("varout",n,name,0))) {
       Replaceall(tm,"$source", name);
@@ -608,7 +595,7 @@ public:
     if (is_assignable(n)) {
       setf = NewWrapper();
       setname = Swig_name_set(iname);
-      Printv(setf->def,"SWIGINTERN char *",setname, "(ClientData clientData SWIGUNUSED, Tcl_Interp *interp, char *name1, char *name2 SWIGUNUSED, int flags) {",NIL);
+      Printv(setf->def,"SWIGINTERN const char *",setname, "(ClientData clientData SWIGUNUSED, Tcl_Interp *interp, char *name1, char *name2 SWIGUNUSED, int flags) {",NIL);
       Wrapper_add_local(setf,"value", "Tcl_Obj *value = 0");
       Wrapper_add_local(setf,"name1o", "Tcl_Obj *name1o = 0");
 
@@ -644,7 +631,7 @@ public:
       if (!readonlywrap) {
 	Wrapper *ro = NewWrapper();
 	Printf(ro->def, "SWIGINTERN const char *swig_readonly(ClientData clientData SWIGUNUSED, Tcl_Interp *interp SWIGUNUSED, char *name1 SWIGUNUSED, char *name2 SWIGUNUSED, int flags SWIGUNUSED) {");
-	Printv(ro->code, "return (char*) \"Variable is read-only\";\n", "}\n", NIL);
+	Printv(ro->code, "return \"Variable is read-only\";\n", "}\n", NIL);
 	Wrapper_print(ro,f_wrappers);
 	readonlywrap = 1;
 	DelWrapper(ro);
@@ -1244,7 +1231,7 @@ public:
     if (!temp) temp = NewString("");
     Clear(temp);
     if (nspace) {
-      Printf(temp,"%s::%s", ns_name,iname);
+      Printf(temp,"%s::%s ", ns_name,iname);
     } else {
       Printf(temp,"%s ", iname);
     }
