@@ -1,18 +1,16 @@
 /* ----------------------------------------------------------------------------- 
+ * See the LICENSE file for information on copyright, usage and redistribution
+ * of SWIG, and the README file for authors - http://www.swig.org/release.html.
+ *
  * scanner.c
  *
- *     This file implements a general purpose C/C++ compatible lexical scanner.
- *     This scanner isn't intended to be plugged directly into a parser built
- *     with yacc. Rather, it contains a lot of generic code that could be used
- *     to easily construct yacc-compatible scanners.
- * 
- * Author(s) : David Beazley (beazley@cs.uchicago.edu)
- *
- * Copyright (C) 1999-2000.  The University of Chicago
- * See the file LICENSE for information on usage and redistribution.	
+ * This file implements a general purpose C/C++ compatible lexical scanner.
+ * This scanner isn't intended to be plugged directly into a parser built
+ * with yacc. Rather, it contains a lot of generic code that could be used
+ * to easily construct yacc-compatible scanners.
  * ----------------------------------------------------------------------------- */
 
-char cvsroot_scanner_c[] = "$Header: /cvsroot/swig/SWIG/Source/Swig/scanner.c,v 1.14 2005/11/28 17:32:56 marcelomatus Exp $";
+char cvsroot_scanner_c[] = "$Header: /cvsroot/swig/SWIG/Source/Swig/scanner.c,v 1.15 2006/03/06 22:51:00 wsfulton Exp $";
 
 #include "swig.h"
 #include <ctype.h>
