@@ -1,15 +1,13 @@
 /* -----------------------------------------------------------------------------
+ * See the LICENSE file for information on copyright, usage and redistribution
+ * of SWIG, and the README file for authors - http://www.swig.org/release.html.
+ *
  * symbol.c
  *
- *     This file implements the SWIG symbol table.  See details below.
- *
- * Author(s) : David Beazley (beazley@cs.uchicago.edu)
- *
- * Copyright (C) 1999-2000.  The University of Chicago
- * See the file LICENSE for information on usage and redistribution.
+ * This file implements the SWIG symbol table.  See details below.
  * ----------------------------------------------------------------------------- */
 
-char cvsroot_symbol_c[] = "$Header: /cvsroot/swig/SWIG/Source/Swig/symbol.c,v 1.51 2006/01/24 22:23:12 marcelomatus Exp $";
+char cvsroot_symbol_c[] = "$Header: /cvsroot/swig/SWIG/Source/Swig/symbol.c,v 1.54 2006/03/20 00:14:23 marcelomatus Exp $";
 
 #include "swig.h"
 #include "swigwarn.h"
@@ -412,6 +410,12 @@ void Swig_symbol_inherit(Symtab *s) {
     Setattr(current_symtab,k_inherit, inherit);
     Delete(inherit);
   }
+
+  if (s == current_symtab) {
+    Swig_warning(WARN_PARSE_REC_INHERITANCE, Getfile(s), Getline(s), 
+		 "Recursive scope inheritance of '%s'.\n", HashGetAttr(s,k_name));
+    return;
+  }
   assert(s != current_symtab);
   ilen = Len(inherit);
   for (i = 0; i < ilen; i++) {
@@ -1411,6 +1415,11 @@ Swig_symbol_type_qualify(const SwigType *t, Symtab *st) {
   List   *elements;
   String *result = NewStringEmpty();
   int     i,len;
+  char  *c = Char(t);
+  if (strncmp(c,"::",2) == 0) {
+    StringAppend(result, t);
+    return result;
+  } 
 
   elements = SwigType_split(t);
 
