@@ -1,22 +1,20 @@
 /* ----------------------------------------------------------------------------- 
+ * See the LICENSE file for information on copyright, usage and redistribution
+ * of SWIG, and the README file for authors - http://www.swig.org/release.html.
+ *
  * tree.c
  *
- *     This file provides some general purpose functions for manipulating 
- *     parse trees.
- * 
- * Author(s) : David Beazley (beazley@cs.uchicago.edu)
- *
- * Copyright (C) 1999-2000.  The University of Chicago
- * See the file LICENSE for information on usage and redistribution.	
+ * This file provides some general purpose functions for manipulating 
+ * parse trees.
  * ----------------------------------------------------------------------------- */
 
+char cvsroot_tree_c[] = "$Header: /cvsroot/swig/SWIG/Source/Swig/tree.c,v 1.21 2006/03/06 22:51:00 wsfulton Exp $";
+
 #include "swig.h"
 #include "swigkeys.h"
 #include <stdarg.h>
 #include <assert.h>
 
-char cvsroot_tree_c[] = "$Header: /cvsroot/swig/SWIG/Source/Swig/tree.c,v 1.20 2006/01/03 09:26:42 marcelomatus Exp $";
-
 /* -----------------------------------------------------------------------------
  * Swig_print_tags()
  *
