@@ -1,15 +1,13 @@
 /* -----------------------------------------------------------------------------
+ * See the LICENSE file for information on copyright, usage and redistribution
+ * of SWIG, and the README file for authors - http://www.swig.org/release.html.
+ *
  * typemap.c
  *
- *     A somewhat generalized implementation of SWIG1.1 typemaps.
- *
- * Author(s) : David Beazley (beazley@cs.uchicago.edu)
- *
- * Copyright (C) 1999-2000.  The University of Chicago
- * See the file LICENSE for information on usage and redistribution.
+ * A somewhat generalized implementation of SWIG1.1 typemaps.
  * ----------------------------------------------------------------------------- */
 
-char cvsroot_typemap_c[] = "$Header: /cvsroot/swig/SWIG/Source/Swig/typemap.c,v 1.68 2006/02/05 20:23:29 marcelomatus Exp $";
+char cvsroot_typemap_c[] = "$Header: /cvsroot/swig/SWIG/Source/Swig/typemap.c,v 1.70 2006/03/06 22:51:00 wsfulton Exp $";
 
 #include "swig.h"
 #include "swigkeys.h"
@@ -1252,7 +1250,8 @@ String *Swig_typemap_lookup_new(const String_or_char *op, Node *node, const Stri
     if (qsn) {
       if (StringLen(qsn) && !Equal(qsn,pname)) {
 	tm = Swig_typemap_search(op,type,qsn,&mtype);
-	if (tm && strstr(Char(Getattr(tm,k_type)),"SWIGTYPE")) {
+	if (tm && (!Getattr(tm,k_pname) || 
+		   strstr(Char(Getattr(tm,k_type)),"SWIGTYPE"))) {
 	  tm = 0;
 	}
       }
