@@ -1,18 +1,16 @@
 /* -----------------------------------------------------------------------------
+ * See the LICENSE file for information on copyright, usage and redistribution
+ * of SWIG, and the README file for authors - http://www.swig.org/release.html.
+ *
  * typesys.c
  *
- *     SWIG type system management.   These functions are used to manage
- *     the C++ type system including typenames, typedef, type scopes, 
- *     inheritance, and namespaces.   Generation of support code for the
- *     run-time type checker is also handled here.
- *
- * Author(s) : David Beazley (beazley@cs.uchicago.edu)
- *
- * Copyright (C) 1999-2000.  The University of Chicago
- * See the file LICENSE for information on usage and redistribution.
+ * SWIG type system management.   These functions are used to manage
+ * the C++ type system including typenames, typedef, type scopes, 
+ * inheritance, and namespaces.   Generation of support code for the
+ * run-time type checker is also handled here.
  * ----------------------------------------------------------------------------- */
 
-char cvsroot_typesys_c[] = "$Header: /cvsroot/swig/SWIG/Source/Swig/typesys.c,v 1.56 2006/02/11 06:13:44 marcelomatus Exp $";
+char cvsroot_typesys_c[] = "$Header: /cvsroot/swig/SWIG/Source/Swig/typesys.c,v 1.59 2006/03/07 22:02:54 wsfulton Exp $";
 
 #include "swig.h"
 #include "swigkeys.h"
@@ -846,6 +844,11 @@ SwigType *SwigType_typedef_qualified(SwigType *t)
   List   *elements;
   String *result;
   int     i,len;
+
+  if (t && strncmp(Char(t),"::",2) == 0) {
+    return Copy(t);
+  }
+  
   if (!typedef_qualified_cache) typedef_qualified_cache = NewHash();
   result = HashGetAttr(typedef_qualified_cache,t);
   if (result) {
@@ -1321,14 +1324,14 @@ SwigType *SwigType_alttype(SwigType *t, int local_tmap) {
   }
 }
 
-/******************************************************************************
- ***                         * * * WARNING * * *                            ***
- ***                                                                        ***
- *** Don't even think about modifying anything below this line unless you   ***
- *** are completely on top of *EVERY* subtle aspect of the C++ type system  ***
- *** and you are prepared to suffer endless hours of agony trying to        ***
- *** debug the SWIG run-time type checker after you break it.               ***
- ******************************************************************************/
+/* ----------------------------------------------------------------------------
+ *                         * * * WARNING * * *                            ***
+ *                                                                        ***
+ * Don't even think about modifying anything below this line unless you   ***
+ * are completely on top of *EVERY* subtle aspect of the C++ type system  ***
+ * and you are prepared to suffer endless hours of agony trying to        ***
+ * debug the SWIG run-time type checker after you break it.               ***
+ * ------------------------------------------------------------------------- */
 
 /* -----------------------------------------------------------------------------
  * SwigType_remember()
